@@ -54,36 +54,37 @@ void cTurtleBoss :: Init( void )
 	m_type = TYPE_TURTLE_BOSS;
 	m_pos_z = 0.092f;
 
-	m_state = STA_WALK;
-	turtle_state = TURTLEBOSS_WALK;	// Walking
-	playercounter = 0;
+	m_player_counter = 0.0f;
+	m_turtle_state = TURTLEBOSS_DEAD;
+	Set_Turtle_Moving_State( TURTLEBOSS_WALK );
 
-	color_type = COL_DEFAULT;
+	m_color_type = COL_DEFAULT;
 	Set_Color( COL_RED );
 	Set_Direction( DIR_RIGHT, 1 );
 
-	fire_resistant = 1;
-	m_ice_resistance = 1;
-	kill_sound = "stomp_4.ogg";
+	m_fire_resistant = 1;
+	m_ice_resistance = 1.0f;
+	m_kill_sound = "stomp_4.ogg";
 
-	hits = 0;
-	downgrade_counts = 0;
+	m_hits = 0;
+	m_downgrade_count = 0;
 
-	max_hits = 3;
-	max_downgrade_counts = 3;
-	shell_time = 2.5f;
+	m_max_hits = 3;
+	m_max_downgrade_count = 3;
+	m_shell_time = 2.5f;
 
-	run_time_counter = 0;
+	m_run_time_counter = 0.0f;
+	m_can_be_hit_from_shell = 0;
 }
 
 cTurtleBoss *cTurtleBoss :: Copy( void )
 {
 	cTurtleBoss *turtle = new cTurtleBoss( m_start_pos_x, m_start_pos_y );
 	turtle->Set_Direction( m_start_direction, 1 );
-	turtle->Set_Color( color_type );
-	turtle->Set_Max_Hits( max_hits );
-	turtle->Set_Max_Downgrade_Counts( max_downgrade_counts );
-	turtle->Set_Shell_Time( shell_time );
+	turtle->Set_Color( m_color_type );
+	turtle->Set_Max_Hits( m_max_hits );
+	turtle->Set_Max_Downgrade_Counts( m_max_downgrade_count );
+	turtle->Set_Shell_Time( m_shell_time );
 
 	return turtle;
 }
@@ -95,13 +96,13 @@ void cTurtleBoss :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 	// direction
 	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( m_start_direction ) ).c_str() ), 1 );
 	// color
-	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
+	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( m_color_type ) ).c_str() )) );
 	// max hits
-	Set_Max_Hits( attributes.getValueAsInteger( "max_hit_count", max_hits ) );
+	Set_Max_Hits( attributes.getValueAsInteger( "max_hit_count", m_max_hits ) );
 	// max downgrade count
-	Set_Max_Downgrade_Counts( attributes.getValueAsInteger( "max_downgrade_count", max_downgrade_counts ) );
+	Set_Max_Downgrade_Counts( attributes.getValueAsInteger( "max_downgrade_count", m_max_downgrade_count ) );
 	// shell time
-	Set_Shell_Time( attributes.getValueAsFloat( "shell_time", shell_time ) );
+	Set_Shell_Time( attributes.getValueAsFloat( "shell_time", m_shell_time ) );
 }
 
 void cTurtleBoss :: Save_To_Stream( ofstream &file )
@@ -115,15 +116,15 @@ void cTurtleBoss :: Save_To_Stream( ofstream &file )
 	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(m_start_pos_x) << "\" />" << std::endl;
 	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(m_start_pos_y) << "\" />" << std::endl;
 	// color
-	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( color_type ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( m_color_type ) << "\" />" << std::endl;
 	// direction
 	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( m_start_direction ) << "\" />" << std::endl;
 	// max hit count
-	file << "\t\t<Property name=\"max_hit_count\" value=\"" << max_hits << "\" />" << std::endl;
+	file << "\t\t<Property name=\"max_hit_count\" value=\"" << m_max_hits << "\" />" << std::endl;
 	// max downgrade count
-	file << "\t\t<Property name=\"max_downgrade_count\" value=\"" << max_downgrade_counts << "\" />" << std::endl;
+	file << "\t\t<Property name=\"max_downgrade_count\" value=\"" << m_max_downgrade_count << "\" />" << std::endl;
 	// shell time
-	file << "\t\t<Property name=\"shell_time\" value=\"" << shell_time << "\" />" << std::endl;
+	file << "\t\t<Property name=\"shell_time\" value=\"" << m_shell_time << "\" />" << std::endl;
 
 	// end enemy
 	file << "\t</enemy>" << std::endl;
@@ -131,31 +132,31 @@ void cTurtleBoss :: Save_To_Stream( ofstream &file )
 
 void cTurtleBoss :: Set_Max_Hits( int nmax_hits )
 {
-	max_hits = nmax_hits;
+	m_max_hits = nmax_hits;
 
-	if( max_hits < 0 )
+	if( m_max_hits < 0 )
 	{
-		max_hits = 0;
+		m_max_hits = 0;
 	}
 }
 
 void cTurtleBoss :: Set_Max_Downgrade_Counts( int nmax_downgrade_counts )
 {
-	max_downgrade_counts = nmax_downgrade_counts;
+	m_max_downgrade_count = nmax_downgrade_counts;
 
-	if( max_downgrade_counts < 0 )
+	if( m_max_downgrade_count < 0 )
 	{
-		max_downgrade_counts = 0;
+		m_max_downgrade_count = 0;
 	}
 }
 
 void cTurtleBoss :: Set_Shell_Time( float nmax_downgrade_time )
 {
-	shell_time = nmax_downgrade_time;
+	m_shell_time = nmax_downgrade_time;
 
-	if( shell_time < 0 )
+	if( m_shell_time < 0.0f )
 	{
-		shell_time = 0;
+		m_shell_time = 0.0f;
 	}
 }
 
@@ -163,86 +164,57 @@ void cTurtleBoss :: Set_Direction( const ObjectDirection dir, bool new_start_dir
 {
 	if( dir != DIR_RIGHT && dir != DIR_LEFT )
 	{
-		printf( "Warning : Unknown Turtle direction set %d\n", dir );
+		printf( "Warning : Unknown Turtle Boss direction set %s\n", Get_Direction_Name( dir ).c_str() );
 		return;
 	}
 
 	cEnemy::Set_Direction( dir, new_start_direction );
-
-	if( m_direction == DIR_RIGHT )
-	{
-		if( turtle_state == TURTLEBOSS_WALK )
-		{
-			m_velx = speed_walk;
-		}
-		else
-		{
-			m_velx = speed_shell;
-		}
-	}
-	else
-	{
-		if( turtle_state == TURTLEBOSS_WALK )
-		{
-			m_velx = -speed_walk;
-		}
-		else
-		{
-			m_velx = -speed_shell;
-		}
-	}
-
+	Update_Velocity();
 	Update_Rotation_Hor_velx( new_start_direction );
 
 	if( new_start_direction )
 	{
 		Create_Name();
 	}
-
-	// if angry turtle
-	if( turtle_state == TURTLEBOSS_STAND_ANGRY )
-	{
-		m_velx = 0;
-	}
 }
 
 void cTurtleBoss :: Set_Color( DefaultColor col )
 {
 	// already set
-	if( color_type == col )
+	if( m_color_type == col )
 	{
 		return;
 	}
 
-	color_type = col;
+	m_color_type = col;
 
 	Clear_Images();
 
-	if( color_type == COL_RED )
+	if( m_color_type == COL_RED )
 	{
 		// Walk
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_0.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_2.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/walk_0.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/walk_2.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/walk_1.png" ) );
 		// Walk Turn
-		//images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/turn_1.png" ) );
-		m_images.push_back( NULL );
+		//Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/turn_1.png" ) );
+		Add_Image( NULL );
 		// Shell
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_front.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_1.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_2.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_3.png" ) );
-		m_images.push_back( pVideo->Get_Surface( "enemy/bosses/turtle/shell_active.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/shell_front.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_1.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_2.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/shell_move_3.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/bosses/turtle/shell_active.png" ) );
 
-		speed_walk = 3.6f;
-		speed_shell = 14;
-		kill_points = 750;
+		m_speed_walk = 3.6f;
+		m_speed_shell = 14.0f;
+		m_kill_points = 750;
 	}
 	// unknown color
 	else
 	{
-		printf( "Error : Unknown TurtleBoss color : %d\n", color_type );
+		printf( "Error : Unknown TurtleBoss color : %d\n", m_color_type );
 	}
 
 	Set_Image_Num( 0, 1 );
@@ -252,11 +224,12 @@ void cTurtleBoss :: Turn_Around( ObjectDirection col_dir /* = DIR_UNDEFINED */ )
 {
 	cEnemy::Turn_Around( col_dir );
 
-	if( turtle_state == TURTLEBOSS_WALK )
+	if( m_turtle_state == TURTLEBOSS_WALK )
 	{
 		// hack : disable turn image
-		//walk_count = 0;
-		//Set_Image( 4 );
+		//Set_Image_Num( 4 );
+		//Set_Animation( 0 );
+		//Reset_Animation();
 	}
 
 	Update_Rotation_Hor_velx();
@@ -267,67 +240,38 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 	if( !force )
 	{
 		// normal walking
-		if( turtle_state == TURTLEBOSS_WALK )
+		if( m_turtle_state == TURTLEBOSS_WALK )
 		{
-			hits++;
-
-			speed_walk += 1.8f;
-
-			if( m_direction == DIR_RIGHT )
-			{
-				m_velx = speed_walk;
-			}
-			else
-			{
-				m_velx = -speed_walk;
-			}
+			m_hits++;
+			m_speed_walk += 1.8f;
 
 			// state change
-			if( hits >= max_hits )
+			if( m_hits >= m_max_hits )
 			{
-				counter = 0;
+				m_counter = 0.0f;
 
-				hits = 0;
-				downgrade_counts++;
+				m_hits = 0;
+				m_downgrade_count++;
 
 				// die
-				if( downgrade_counts == max_downgrade_counts )
+				if( m_downgrade_count == m_max_downgrade_count )
 				{
 					Set_Dead( 1 );
 				}
 				// downgrade
 				else
 				{
-					m_state = STA_STAY;
-					turtle_state = TURTLEBOSS_STAND_ANGRY;
-
-					speed_shell += 3;
-					m_velx = 0;
+					m_speed_shell += 3.0f;
+					Set_Turtle_Moving_State( TURTLEBOSS_STAND_ANGRY );
 				}
 			}
+
+			Update_Velocity();
 		}
 		// staying
-		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
+		else if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
-			counter = 0;
-			m_state = STA_RUN;
-			turtle_state = TURTLEBOSS_SHELL_RUN;
-			m_player_range = 5000;
-
-			// move into random direction
-			if( rand() % 2 != 1 )
-			{
-				// right
-				m_velx = speed_shell;
-			}
-			else
-			{
-				// left
-				m_velx = -speed_shell;
-			}
-
-			Update_Direction();
-			Update_Rotation_Hor_velx();
+			Set_Turtle_Moving_State( TURTLEBOSS_SHELL_RUN );
 		}
 	}
 	// falling death
@@ -336,13 +280,13 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 		// die
 		Set_Dead( 1 );
 
-		if( turtle_state == TURTLEBOSS_WALK )
+		if( m_turtle_state == TURTLEBOSS_WALK )
 		{
-			Move( 0, m_images[0]->m_h - m_images[5]->m_h, 1 );
+			Move( 0.0f, m_images[0].m_image->m_h - m_images[5].m_image->m_h, 1 );
 		}
 	}
 
-	if( dead )
+	if( m_dead )
 	{
 		// fade out music
 		pAudio->Fadeout_Music( 500 );
@@ -353,22 +297,22 @@ void cTurtleBoss :: DownGrade( bool force /* = 0 */ )
 		Set_Image_Num( 5 );
 
 		m_massive_type = MASS_PASSIVE;
-		counter = 0;
-		m_velx = 0;
-		m_vely = 0;
+		m_counter = 0.0f;
+		m_velx = 0.0f;
+		m_vely = 0.0f;
 
 		// set scaling for death animation
 		Set_Scale_Affects_Rect( 1 );
 	}
 }
 
-void cTurtleBoss :: DieStep( void )
+void cTurtleBoss :: Update_Dying( void )
 {
-	counter += pFramerate->speedfactor * 0.5f;
+	m_counter += pFramerate->m_speed_factor * 0.5f;
 
 	if( m_scale_x > 0.1f )
 	{
-		float speed_x = pFramerate->speedfactor * 10;
+		float speed_x = pFramerate->m_speed_factor * 10.0f;
 
 		if( m_direction == DIR_LEFT )
 		{
@@ -376,13 +320,13 @@ void cTurtleBoss :: DieStep( void )
 		}
 
 		Add_Rotation_Z( speed_x );
-		Add_Scale( -pFramerate->speedfactor * 0.025f );
+		Add_Scale( -pFramerate->m_speed_factor * 0.025f );
 
 		// star animation
-		if( counter >= 1 )
+		if( m_counter >= 1.0f )
 		{
-			Generate_Stars( static_cast<unsigned int>(counter), 0.1f );
-			counter -= static_cast<int>(counter);
+			Generate_Stars( static_cast<unsigned int>(m_counter), 0.1f );
+			m_counter -= static_cast<int>(m_counter);
 		}
 
 		// finished scale out animation
@@ -397,17 +341,17 @@ void cTurtleBoss :: DieStep( void )
 			// set empty image
 			cMovingSprite::Set_Image( NULL, 0, 0 );
 			// reset counter
-			counter = 0;
+			m_counter = 0;
 		}
 	}
 	// after scale animation
 	else
 	{
 		// wait some time
-		if( counter > 20 )
+		if( m_counter > 20.0f )
 		{
 			Set_Active( 0 );
-			turtle_state = TURTLEBOSS_DEAD;
+			m_turtle_state = TURTLEBOSS_DEAD;
 
 			// next level
 			pPlayer->Goto_Next_Level();
@@ -418,6 +362,68 @@ void cTurtleBoss :: DieStep( void )
 	}
 }
 
+void cTurtleBoss :: Set_Turtle_Moving_State( TurtleBoss_state new_state )
+{
+	if( new_state == m_turtle_state )
+	{
+		return;
+	}
+
+	if( new_state == TURTLEBOSS_WALK )
+	{
+		m_state = STA_WALK;
+		m_player_range = 1500;
+
+		Set_Animation( 1 );
+		Set_Animation_Image_Range( 0, 3 );
+		Set_Time_All( 220, 1 );
+		Reset_Animation();
+		Set_Image_Num( m_anim_img_start );
+	}
+	else if( new_state == TURTLEBOSS_STAND_ANGRY )
+	{
+		m_state = STA_STAY;
+		m_velx = 0.0f;
+
+		Set_Animation( 0 );
+	}
+	else if( new_state == TURTLEBOSS_SHELL_STAND )
+	{
+		m_state = STA_STAY;
+		m_player_range = 2000;
+
+		Set_Animation( 0 );
+		// set stay image
+		Set_Animation_Image_Range( 5, 5 );
+		Set_Image_Num( m_anim_img_start );
+	}
+	else if( new_state == TURTLEBOSS_SHELL_RUN )
+	{
+		m_counter = 0.0f;
+		m_state = STA_RUN;
+		m_player_range = 5000;
+
+		Set_Animation( 1 );
+		Set_Animation_Image_Range( 6, 9 );
+		Set_Time_All( 80, 1 );
+		Reset_Animation();
+		Set_Image_Num( m_anim_img_start );
+	}
+
+	m_turtle_state = new_state;
+
+	if( m_turtle_state == TURTLEBOSS_WALK )
+	{
+		Update_Velocity();
+		Update_Rotation_Hor_velx();
+	}
+	else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
+	{
+		Update_Velocity();
+		Update_Rotation_Hor_velx();
+	}
+}
+
 void cTurtleBoss :: Update( void )
 {
 	cEnemy::Update();
@@ -427,60 +433,43 @@ void cTurtleBoss :: Update( void )
 		return;
 	}
 
+	Update_Animation();
+
 	// walking
-	if( turtle_state == TURTLEBOSS_WALK )
+	if( m_turtle_state == TURTLEBOSS_WALK )
 	{
-		walk_count += pFramerate->speedfactor * 0.3f;
+		m_anim_counter += pFramerate->m_elapsed_ticks;
 
-		// if not turn around image
-		if( m_curr_img != 4 )
+		// if turn around image
+		if( m_curr_img == 4 )
 		{
-			if( walk_count >= 4 )
+			// set normal image back
+			if( m_anim_counter >= 200 )
 			{
-				walk_count = 0;
-			}
-
-			Set_Image_Num( static_cast<int>(walk_count) );
-		}
-		// turn around image
-		else
-		{
-			// force the new image
-			if( walk_count >= 4 )
-			{
-				Set_Image_Num( static_cast<int>(walk_count) );
+				Set_Animation( 1 );
+				Reset_Animation();
+				Set_Image_Num( m_anim_img_start );
 				Update_Rotation_Hor_velx();
 			}
 			// rotate the turn image
-			else if( walk_count >= 2 )
+			else if( m_anim_counter >= 100 )
 			{
-				if( m_velx < 0 )
-				{
-					m_rot_y = 180;
-				}
-				else
-				{
-					m_rot_y = 0;
-				}
+				Update_Rotation_Hor_velx();
 			}
 		}
 	}
 	// standing shell
-	else if( turtle_state == TURTLEBOSS_SHELL_STAND )
+	else if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
-		counter += pFramerate->speedfactor;
+		m_counter += pFramerate->m_speed_factor;
 
-		// waiting
-		if( counter < 160 )
-		{
-			Set_Image_Num( 5 ); // front
-		}
-		else
+		// stop waiting
+		if( m_counter > 160.0f )
 		{
 			// animation
-			if( counter < 192 )
+			if( m_counter < 192.0f )
 			{
-				if( static_cast<int>(counter) % 5 == 1 )
+				if( static_cast<int>(m_counter) % 5 == 1 )
 				{
 					Set_Image_Num( 9 ); // active
 				}
@@ -492,73 +481,64 @@ void cTurtleBoss :: Update( void )
 			// activate
 			else
 			{
-				counter = 0;
+				m_counter = 0.0f;
 				Stand_Up();
 			}
 		}
 
-
-		if( m_velx != 0 )
+		// slow down
+		if( !Is_Float_Equal( m_velx, 0.0f ) )
 		{
-			Add_Velocity( -m_velx * 0.2f, 0 );
+			Add_Velocity( -m_velx * 0.2f, 0.0f );
 
 			if( m_velx < 0.3f && m_velx > -0.3f )
 			{
-				m_velx = 0;
+				m_velx = 0.0f;
 			}
 		}
 	}
 	// moving shell
-	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
+	else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
-		run_time_counter += pFramerate->speedfactor;
+		m_run_time_counter += pFramerate->m_speed_factor;
 		// time = seconds since start
-		float time = run_time_counter / speedfactor_fps;
+		float time = m_run_time_counter / speedfactor_fps;
 
-		if( time > shell_time )
+		if( time > m_shell_time )
 		{
-			run_time_counter = 0;
+			m_run_time_counter = 0.0f;
 			Stand_Up();
-
-			return;
 		}
-
-		walk_count += pFramerate->speedfactor * 0.4f;
-
-		if( playercounter > 0 )
+		else
 		{
-			playercounter -= pFramerate->speedfactor;
-
-			if( playercounter <= 0 )
+			if( m_player_counter > 0.0f )
 			{
-				// do not start collision detection if in maryo
-				if( pPlayer->m_col_rect.Intersects( m_col_rect ) )
+				m_player_counter -= pFramerate->m_speed_factor;
+
+				if( m_player_counter <= 0.0f )
 				{
-					playercounter = 5;
-				}
-				else
-				{
-					playercounter = 0;
+					// do not start collision detection if colliding with maryo
+					if( pPlayer->m_col_rect.Intersects( m_col_rect ) )
+					{
+						m_player_counter = 5.0f;
+					}
+					else
+					{
+						m_player_counter = 0.0f;
+					}
 				}
 			}
 		}
-
-		if( walk_count >= 3 )
-		{
-			walk_count = 0;
-		}
-
-		Set_Image_Num( 6 + static_cast<int>(walk_count) );
 	}
-	else if( turtle_state == TURTLEBOSS_STAND_ANGRY )
+	else if( m_turtle_state == TURTLEBOSS_STAND_ANGRY )
 	{
-		counter += pFramerate->speedfactor;
+		m_counter += pFramerate->m_speed_factor;
 
 		// angry
-		if( static_cast<int>(counter) % 2 == 1 )
+		if( static_cast<int>(m_counter) % 2 == 1 )
 		{
 			// slowly fade to the color
-			cMovingSprite::Set_Color( Color( static_cast<Uint8>(255), 250 - static_cast<Uint8>( counter * 1.5f ), 250 - static_cast<Uint8>( counter * 4 ) ) );
+			cMovingSprite::Set_Color( Color( static_cast<Uint8>(255), 250 - static_cast<Uint8>( m_counter * 1.5f ), 250 - static_cast<Uint8>( m_counter * 4 ) ) );
 		}
 		// default
 		else
@@ -567,7 +547,7 @@ void cTurtleBoss :: Update( void )
 		}
 
 		// randomize direction
-		if( ( static_cast<int>(counter) / 10 ) % 2 == 1 )
+		if( ( static_cast<int>(m_counter) / 10 ) % 2 == 1 )
 		{
 			if( m_direction == DIR_RIGHT )
 			{
@@ -583,31 +563,17 @@ void cTurtleBoss :: Update( void )
 		}
 
 		// finished animation
-		if( counter > 60 )
+		if( m_counter > 60.0f )
 		{
-			counter = 0;
-
-			// running shell for some time
-			turtle_state = TURTLEBOSS_SHELL_RUN;
-			m_state = STA_RUN;
-
+			m_counter = 0.0f;
 			// shell attack sound
 			pAudio->Play_Sound( "enemy/boss/turtle/shell_attack.ogg" );
 
-			// throw more fireballs with downgrades
-			Throw_Fireballs( 6 + ( downgrade_counts * 2 ) );
+			Set_Turtle_Moving_State( TURTLEBOSS_SHELL_RUN );
+			Col_Move( 0.0f, m_images[0].m_image->m_col_h - m_images[5].m_image->m_col_h, 1, 1 );
 
-			Col_Move( 0, m_images[0]->m_col_h - m_images[5]->m_col_h, 1, 1 );
-			Set_Image_Num( 5 );
-
-			if( m_direction == DIR_RIGHT )
-			{
-				m_velx = speed_shell;
-			}
-			else
-			{
-				m_velx = -speed_shell;
-			}
+			// throw more fireballs with each downgrade
+			Throw_Fireballs( 6 + ( m_downgrade_count * 2 ) );
 		}
 	}
 
@@ -617,15 +583,15 @@ void cTurtleBoss :: Update( void )
 
 void cTurtleBoss :: Stand_Up( void )
 {
-	if( turtle_state != TURTLEBOSS_SHELL_STAND && turtle_state != TURTLEBOSS_SHELL_RUN )
+	if( m_turtle_state != TURTLEBOSS_SHELL_STAND && m_turtle_state != TURTLEBOSS_SHELL_RUN )
 	{
 		return;
 	}
 
 	// get space needed to stand up
-	float move_y = m_image->m_col_h - m_images[0]->m_col_h;
+	float move_y = m_image->m_col_h - m_images[0].m_image->m_col_h;
 
-	cObjectCollisionType *col_list = Collision_Check_Relative( 0, move_y, 0, 0, COLLIDE_ONLY_BLOCKING );
+	cObjectCollisionType *col_list = Collision_Check_Relative( 0.0f, move_y, 0.0f, 0.0f, COLLIDE_ONLY_BLOCKING );
 
 	// failed to stand up because something is blocking
 	if( !col_list->empty() )
@@ -636,27 +602,9 @@ void cTurtleBoss :: Stand_Up( void )
 
 	delete col_list;
 
-	turtle_state = TURTLEBOSS_WALK;
-	m_state = STA_WALK;
-
-	if( m_direction == DIR_RIGHT )
-	{
-		m_velx = speed_walk;
-	}
-	else
-	{
-		m_velx = -speed_walk;
-	}
-
-	Update_Direction();
-	Update_Rotation_Hor_velx();
-
 	pAudio->Play_Sound( "enemy/boss/turtle/power_up.ogg" );
-
-	Col_Move( 0, move_y, 1, 1 );
-
-	// set walking image
-	Set_Image_Num( static_cast<int>(walk_count) );
+	Col_Move( 0.0f, move_y, 1, 1 );
+	Set_Turtle_Moving_State( TURTLEBOSS_WALK );
 }
 
 bool cTurtleBoss :: Hit_Enemy( cEnemy *enemy ) const
@@ -668,14 +616,14 @@ bool cTurtleBoss :: Hit_Enemy( cEnemy *enemy ) const
 	}
 
 	// don't collide with already dead enemies
-	if( enemy->dead )
+	if( enemy->m_dead )
 	{
 		return 0;
 	}
 
 	// hit enemy
-	pAudio->Play_Sound( enemy->kill_sound );
-	pHud_Points->Add_Points( enemy->kill_points, m_pos_x + m_image->m_w / 3, m_pos_y - 5, "", static_cast<Uint8>(255), 1 );
+	pAudio->Play_Sound( enemy->m_kill_sound );
+	pHud_Points->Add_Points( enemy->m_kill_points, m_pos_x + m_image->m_w / 3, m_pos_y - 5.0f, "", static_cast<Uint8>(255), 1 );
 	enemy->DownGrade( 1 );
 	pPlayer->Add_Kill_Multiplier();
 
@@ -685,9 +633,9 @@ bool cTurtleBoss :: Hit_Enemy( cEnemy *enemy ) const
 void cTurtleBoss :: Throw_Fireballs( unsigned int amount /* = 6 */ )
 {
 	// start angle
-	float ball_angle = -180;
+	float ball_angle = -180.0f;
 	// move 180 degrees
-	float step_size = 180 / static_cast<float>(amount);
+	float step_size = 180.0f / amount;
 
 	for( unsigned int i = 0; i < amount; i++ )
 	{
@@ -696,7 +644,7 @@ void cTurtleBoss :: Throw_Fireballs( unsigned int amount /* = 6 */ )
 
 		cBall *ball = new cBall( m_pos_x + m_col_rect.m_w / 2, m_pos_y + m_col_rect.m_h / 2, this, FIREBALL_EXPLOSION );
 		ball->Set_Direction( ball_angle, 15 );
-		ball->Col_Move( ball->m_velx * 2, ball->m_vely * 2, 1 );
+		ball->Col_Move( ball->m_velx * 2.0f, ball->m_vely * 2.0f, 1 );
 		pActive_Sprite_Manager->Add( ball );
 	}
 
@@ -723,9 +671,46 @@ void cTurtleBoss :: Generate_Stars( unsigned int amount /* = 1 */, float particl
 	pAnimation_Manager->Add( anim );
 }
 
+void cTurtleBoss :: Update_Velocity( void )
+{
+	// update velocity
+	if( m_direction == DIR_RIGHT )
+	{
+		if( m_turtle_state == TURTLEBOSS_WALK )
+		{
+			m_velx = m_speed_walk;
+		}
+		else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
+		{
+			m_velx = m_speed_shell;
+		}
+		else if( m_turtle_state == TURTLEBOSS_STAND_ANGRY )
+		{
+			m_velx = 0.0f;
+		}
+		// shell stay does slow down automatically
+	}
+	else
+	{
+		if( m_turtle_state == TURTLEBOSS_WALK )
+		{
+			m_velx = -m_speed_walk;
+		}
+		else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
+		{
+			m_velx = -m_speed_shell;
+		}
+		else if( m_turtle_state == TURTLEBOSS_STAND_ANGRY )
+		{
+			m_velx = 0.0f;
+		}
+		// shell stay does slow down automatically
+	}
+}
+
 bool cTurtleBoss :: Is_Update_Valid( void )
 {
-	if( dead || m_freeze_counter )
+	if( m_dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -739,88 +724,117 @@ Col_Valid_Type cTurtleBoss :: Validate_Collision( cSprite *obj )
 	Col_Valid_Type basic_valid = Validate_Collision_Ghost( obj );
 
 	// found valid collision
-	if( basic_valid != COL_VTYPE_NO_GHOST )
+	if( basic_valid != COL_VTYPE_NOT_POSSIBLE )
 	{
 		return basic_valid;
 	}
 
 	if( obj->m_massive_type == MASS_MASSIVE )
 	{
-		if( obj->m_type == TYPE_PLAYER )
+		switch( obj->m_type )
 		{
-			// player is invincible
-			if( pPlayer->invincible )
+			case TYPE_PLAYER:
 			{
-				return COL_VTYPE_NOT_VALID;
+				// player is invincible
+				if( pPlayer->invincible )
+				{
+					return COL_VTYPE_NOT_VALID;
+				}
+				// player counter is active
+				if( m_turtle_state == TURTLEBOSS_SHELL_RUN && m_player_counter > 0.0f )
+				{
+					return COL_VTYPE_NOT_VALID;
+				}
+
+				break;
 			}
-			// player counter is active
-			if( turtle_state == TURTLEBOSS_SHELL_RUN && playercounter > 0 )
-			{
-				return COL_VTYPE_NOT_VALID;
-			}
-		}
-		else if( obj->m_sprite_array == ARRAY_ENEMY )
-		{
-			if( obj->m_type == TYPE_FLYON )
+			case TYPE_FLYON:
 			{
 				// if walking
-				if( turtle_state == TURTLEBOSS_WALK )
+				if( m_turtle_state == TURTLEBOSS_WALK )
 				{
 					return COL_VTYPE_NOT_VALID;
 				}
 				// shell
-				if( turtle_state == TURTLEBOSS_SHELL_STAND || turtle_state == TURTLEBOSS_SHELL_RUN )
+				if( m_turtle_state == TURTLEBOSS_SHELL_STAND || m_turtle_state == TURTLEBOSS_SHELL_RUN )
 				{
 					return COL_VTYPE_INTERNAL;
 				}
+
+				break;
 			}
-			if( obj->m_type == TYPE_ROKKO )
+			case TYPE_ROKKO:
 			{
 				return COL_VTYPE_NOT_VALID;
 			}
-			if( obj->m_type == TYPE_GEE )
+			case TYPE_GEE:
 			{
-				if( turtle_state == TURTLEBOSS_SHELL_STAND || turtle_state == TURTLEBOSS_SHELL_RUN )
+				if( m_turtle_state == TURTLEBOSS_SHELL_STAND || m_turtle_state == TURTLEBOSS_SHELL_RUN )
 				{
 					return COL_VTYPE_INTERNAL;
 				}
 
 				return COL_VTYPE_NOT_VALID;
 			}
-			if( obj->m_type == TYPE_STATIC_ENEMY )
+			case TYPE_STATIC_ENEMY:
 			{
 				return COL_VTYPE_NOT_VALID;
 			}
+			case TYPE_SPIKEBALL:
+			{
+				if( m_turtle_state == TURTLEBOSS_SHELL_STAND || m_turtle_state == TURTLEBOSS_SHELL_RUN )
+				{
+					return COL_VTYPE_INTERNAL;
+				}
 
+				return COL_VTYPE_NOT_VALID;
+			}
+			case TYPE_BALL:
+			{
+				return COL_VTYPE_NOT_VALID;	
+			}
+			default:
+			{
+				break;
+			}
+		}
+
+		if( obj->m_sprite_array == ARRAY_ENEMY )
+		{
 			// if moving shell don't collide with enemies
-			if( turtle_state == TURTLEBOSS_SHELL_RUN )
+			if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 			{
 				return COL_VTYPE_INTERNAL;
 			}
 		}
-		// ignore balls
-		else if( obj->m_type == TYPE_BALL )
-		{
-			return COL_VTYPE_NOT_VALID;
-		}
 
 		return COL_VTYPE_BLOCKING;
 	}
-	if( obj->m_type == TYPE_ENEMY_STOPPER )
+	else if( obj->m_massive_type == MASS_HALFMASSIVE )
 	{
-		if( turtle_state == TURTLEBOSS_WALK )
+		// if moving downwards and the object is on bottom
+		if( m_vely >= 0.0f && Is_On_Top( obj ) )
 		{
 			return COL_VTYPE_BLOCKING;
 		}
-
-		return COL_VTYPE_NOT_VALID;
 	}
-	if( obj->m_massive_type == MASS_HALFMASSIVE )
+	else if( obj->m_massive_type == MASS_PASSIVE )
 	{
-		// if moving downwards and the object is on bottom
-		if( m_vely >= 0 && Is_On_Top( obj ) )
+		switch( obj->m_type )
 		{
-			return COL_VTYPE_BLOCKING;
+			case TYPE_ENEMY_STOPPER:
+			{
+				if( m_turtle_state == TURTLEBOSS_WALK )
+				{
+					return COL_VTYPE_BLOCKING;
+				}
+
+				return COL_VTYPE_NOT_VALID;
+			}
+			default:
+			{
+				break;
+			}
 		}
 	}
 
@@ -829,18 +843,18 @@ Col_Valid_Type cTurtleBoss :: Validate_Collision( cSprite *obj )
 
 void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 {
-	if( collision->direction == DIR_UNDEFINED || ( turtle_state == TURTLEBOSS_SHELL_RUN && playercounter > 0 ) || m_state == STA_OBJ_LINKED )
+	if( collision->direction == DIR_UNDEFINED || ( m_turtle_state == TURTLEBOSS_SHELL_RUN && m_player_counter > 0.0f ) || m_state == STA_OBJ_LINKED )
 	{
 		return;
 	}
 
 	if( collision->direction == DIR_TOP && pPlayer->m_state != STA_FLY )
 	{
-		if( turtle_state == TURTLEBOSS_WALK )
+		if( m_turtle_state == TURTLEBOSS_WALK )
 		{
 			pHud_Points->Add_Points( 250, pPlayer->m_pos_x, pPlayer->m_pos_y );
 
-			if( hits + 1 == max_hits )
+			if( m_hits + 1 == m_max_hits )
 			{
 				pAudio->Play_Sound( "enemy/boss/turtle/big_hit.ogg" );
 			}
@@ -849,12 +863,12 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 				pAudio->Play_Sound( "enemy/boss/turtle/hit.ogg" );
 			}
 		}
-		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
+		else if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
 			pHud_Points->Add_Points( 100, pPlayer->m_pos_x, pPlayer->m_pos_y );
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 		}
-		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
+		else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
 			pHud_Points->Add_Points( 50, pPlayer->m_pos_x, pPlayer->m_pos_y );
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
@@ -873,17 +887,17 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 		DownGrade();
 
 		// if now running
-		if( turtle_state == TURTLEBOSS_SHELL_RUN )
+		if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
 			// if player is on the left side
 			if( ( pPlayer->m_col_rect.m_w / 2 ) + pPlayer->m_pos_x < ( m_col_rect.m_w / 2 ) + m_pos_x )
 			{
-				m_velx = speed_shell;
+				Set_Direction( DIR_RIGHT );
 			}
-			// on the right side
+			// right side
 			else
 			{
-				m_velx = -speed_shell;
+				Set_Direction( DIR_LEFT );
 			}
 
 			Update_Direction();
@@ -893,50 +907,17 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 	}
 	else
 	{
-		if( turtle_state == TURTLEBOSS_WALK )
+		if( m_turtle_state == TURTLEBOSS_WALK )
 		{
 			pPlayer->DownGrade_Player();
 			Turn_Around( collision->direction );
 		}
-		else if( turtle_state == TURTLEBOSS_SHELL_STAND )
+		else if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 		{
 			pAudio->Play_Sound( "enemy/turtle/shell/hit.ogg" );
 			DownGrade();
 
-			cParticle_Emitter *anim = NULL;
-
-			if( collision->direction == DIR_RIGHT )
-			{
-				anim = new cParticle_Emitter();
-				anim->Set_Pos( m_pos_x + m_col_pos.m_x + m_col_rect.m_w, m_pos_y + ( m_col_rect.m_h / 2 ) );
-				anim->Set_Direction_Range( 90, 180 );
-				m_velx = -speed_shell;
-			}
-			else if( collision->direction == DIR_LEFT )
-			{
-				anim = new cParticle_Emitter();
-				anim->Set_Pos( m_pos_x, m_pos_y + ( m_col_rect.m_h / 2 ) );
-				anim->Set_Direction_Range( 270, 180 );
-				m_velx = speed_shell;
-			}
-			else
-			{
-				anim = new cParticle_Emitter();
-				anim->Set_Pos( m_pos_x + ( m_col_rect.m_w / 2 ), m_pos_y + m_col_pos.m_y + m_col_rect.m_h );
-				anim->Set_Direction_Range( 180, 180 );
-
-				// if player is on the left side
-				if( ( pPlayer->m_col_rect.m_w / 2 ) + pPlayer->m_pos_x < ( m_col_rect.m_w / 2 ) + m_pos_x )
-				{
-					m_velx = speed_shell;
-				}
-				// on the right side
-				else
-				{
-					m_velx = -speed_shell;
-				}
-			}
-
+			cParticle_Emitter *anim = new cParticle_Emitter();
 			anim->Set_Image( pVideo->Get_Surface( "animation/particles/light.png" ) );
 			anim->Set_Quota( 4 );
 			anim->Set_Pos_Z( m_pos_z + 0.0001f );
@@ -945,34 +926,62 @@ void cTurtleBoss :: Handle_Collision_Player( cObjectCollision *collision )
 			anim->Set_Scale( 0.8f );
 			anim->Set_Fading_Size( 1 );
 			anim->Set_Color( Color( static_cast<Uint8>(254), 200, 100 ) );
-			pAnimation_Manager->Add( anim );
-			
-			Update_Direction();
 
-			playercounter = speedfactor_fps * 0.13f;
-
-			// small upwards kick
-			if( collision->direction == DIR_BOTTOM )
+			if( collision->direction == DIR_RIGHT )
 			{
-				m_vely = -5 + (pPlayer->m_vely * 0.3f);
+				anim->Set_Pos( m_pos_x + m_col_pos.m_x + m_col_rect.m_w, m_pos_y + ( m_col_rect.m_h / 2 ) );
+				anim->Set_Direction_Range( 90.0f, 180.0f );
+				Set_Direction( DIR_LEFT );
 			}
+			else if( collision->direction == DIR_LEFT )
+			{
+				anim->Set_Pos( m_pos_x, m_pos_y + ( m_col_rect.m_h / 2 ) );
+				anim->Set_Direction_Range( 270.0f, 180.0f );
+				Set_Direction( DIR_RIGHT );
+			}
+			else
+			{
+				anim->Set_Pos( m_pos_x + ( m_col_rect.m_w / 2 ), m_pos_y + m_col_pos.m_y + m_col_rect.m_h );
+				anim->Set_Direction_Range( 180.0f, 180.0f );
+
+				// if player is on the left side
+				if( ( pPlayer->m_col_rect.m_w / 2 ) + pPlayer->m_pos_x < ( m_col_rect.m_w / 2 ) + m_pos_x )
+				{
+					Set_Direction( DIR_RIGHT );
+				}
+				// right side
+				else
+				{
+					Set_Direction( DIR_LEFT );
+				}
+
+				// small upwards kick
+				if( collision->direction == DIR_BOTTOM )
+				{
+					m_vely = -5.0f + (pPlayer->m_vely * 0.3f);
+				}
+			}
+
+			pAnimation_Manager->Add( anim );
+			m_player_counter = speedfactor_fps * 0.13f;
 		}
-		else if( turtle_state == TURTLEBOSS_SHELL_RUN )
+		else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 		{
 			// bottom kicks upwards
 			if( collision->direction == DIR_BOTTOM )
 			{
 				// small upwards kick
-				if( collision->direction == DIR_BOTTOM )
-				{
-					m_vely = -5 + (pPlayer->m_vely * 0.3f);
-				}
+				m_vely = -5.0f + (pPlayer->m_vely * 0.3f);
 			}
 			// other directions downgrade
 			else
 			{
 				pPlayer->DownGrade_Player();
-				Turn_Around( collision->direction );
+
+				if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
+				{
+					Turn_Around( collision->direction );
+				}
 			}
 		}
 	}
@@ -982,19 +991,19 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 {
 	cEnemy *enemy = static_cast<cEnemy *>(pActive_Sprite_Manager->Get_Pointer( collision->number ));
 
-	if( turtle_state == TURTLEBOSS_SHELL_STAND )
+	if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
 		// if able to collide
-		if( m_vely < -5 )
+		if( m_vely < -5.0f )
 		{
 			Hit_Enemy( enemy );
 		}
 	}
-	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
+	else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
 		Hit_Enemy( enemy );
 	}
-	else if( turtle_state == TURTLEBOSS_WALK )
+	else if( m_turtle_state == TURTLEBOSS_WALK )
 	{
 		// turtle shell
 		if( enemy->m_type == TYPE_TURTLE && enemy->m_state == STA_RUN )
@@ -1003,7 +1012,11 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 		}
 		else
 		{
-			Turn_Around( collision->direction );
+			if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
+			{
+				Turn_Around( collision->direction );
+			}
+
 			Send_Collision( collision );
 		}
 	}
@@ -1011,11 +1024,11 @@ void cTurtleBoss :: Handle_Collision_Enemy( cObjectCollision *collision )
 
 void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 {
-	if( turtle_state == TURTLEBOSS_WALK )
+	if( m_turtle_state == TURTLEBOSS_WALK )
 	{
-		//
+		Send_Collision( collision );
 	}
-	else if( turtle_state == TURTLEBOSS_SHELL_RUN )
+	else if( m_turtle_state == TURTLEBOSS_SHELL_RUN )
 	{
 		if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
 		{
@@ -1027,20 +1040,20 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 			{
 				anim = new cParticle_Emitter();
 				anim->Set_Pos( col_object->m_pos_x + col_object->m_col_pos.m_x + 4, m_pos_y + ( m_col_rect.m_h / 1.35f ) );
-				anim->Set_Direction_Range( 140, 100 );
+				anim->Set_Direction_Range( 140.0f, 100.0f );
 			}
 			else
 			{
 				anim = new cParticle_Emitter();
 				anim->Set_Pos( col_object->m_pos_x + col_object->m_col_pos.m_x + col_object->m_col_rect.m_w - 4, m_pos_y + ( m_col_rect.m_h / 1.35f ) );
-				anim->Set_Direction_Range( 320, 100 );
+				anim->Set_Direction_Range( 320.0f, 100.0f );
 			}
 
 			anim->Set_Image( pVideo->Get_Surface( "animation/particles/smoke.png" ) );
 			anim->Set_Quota( 5 );
-			anim->Set_Time_to_Live( 0.3f );
 			anim->Set_Pos_Z( col_object->m_pos_z - 0.0001f, 0.0002f );
-			anim->Set_Speed( 1, 1 );
+			anim->Set_Time_to_Live( 0.3f );
+			anim->Set_Speed( 1.0f, 1.0f );
 			anim->Set_Scale( 0.5f, 0.4f );
 			// add animation
 			pAnimation_Manager->Add( anim );
@@ -1052,10 +1065,10 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 			Send_Collision( collision );
 		}
 	}
-	else if( turtle_state == TURTLEBOSS_SHELL_STAND )
+	else if( m_turtle_state == TURTLEBOSS_SHELL_STAND )
 	{
 		// if able to collide
-		if( m_vely < -5 )
+		if( m_vely < -5.0f )
 		{
 			// active object box collision
 			if( collision->m_array == ARRAY_ACTIVE )
@@ -1071,7 +1084,7 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 					// if useable
 					if( box->useable_count != 0 )
 					{
-						pHud_Points->Add_Points( 50, m_pos_x + m_image->m_w / 3, m_pos_y - 5 );
+						pHud_Points->Add_Points( 50, m_pos_x + m_image->m_w / 3, m_pos_y - 5.0f );
 						Send_Collision( collision );
 						DownGrade( 1 );
 					}
@@ -1082,19 +1095,19 @@ void cTurtleBoss :: Handle_Collision_Massive( cObjectCollision *collision )
 	
 	if( collision->direction == DIR_TOP )
 	{
-		if( m_vely > 0 )
+		if( m_vely > 0.0f )
 		{
-			m_vely = 0;
+			m_vely = 0.0f;
 		}
 	}
 	else if( collision->direction == DIR_BOTTOM )
 	{
-		if( m_vely < 0 )
+		if( m_vely < 0.0f )
 		{
-			m_vely = 0;
+			m_vely = 0.0f;
 		}
 	}
-	else
+	else if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
 	{
 		Turn_Around( collision->direction );
 	}
@@ -1120,7 +1133,7 @@ void cTurtleBoss :: Editor_Activate( void )
 	Editor_Add( UTF8_("Hits"), UTF8_("Hits until a downgrade"), editbox, 120 );
 
 	editbox->setValidationString( "^[+]?\\d*$" );
-	editbox->setText( int_to_string( max_hits ) );
+	editbox->setText( int_to_string( m_max_hits ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Hits_Text_Changed, this ) );
 
 	// max downgrades
@@ -1128,7 +1141,7 @@ void cTurtleBoss :: Editor_Activate( void )
 	Editor_Add( UTF8_("Downgrades"), UTF8_("Downgrades until death"), editbox, 120 );
 
 	editbox->setValidationString( "^[+]?\\d*$" );
-	editbox->setText( int_to_string( max_downgrade_counts ) );
+	editbox->setText( int_to_string( m_max_downgrade_count ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Max_Downgrade_Counts_Text_Changed, this ) );
 
 	// max shell time
@@ -1136,7 +1149,7 @@ void cTurtleBoss :: Editor_Activate( void )
 	Editor_Add( UTF8_("Shell Time"), UTF8_("Time running as shell to rise again"), editbox, 200 );
 
 	editbox->setValidationString( "[+]?[0-9]*\\.?[0-9]*" );
-	editbox->setText( float_to_string( shell_time ) );
+	editbox->setText( float_to_string( m_shell_time ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cTurtleBoss::Editor_Shell_Time_Text_Changed, this ) );
 
 	// init
