@@ -19,6 +19,7 @@
 #include "../player/player.h"
 #include "../video/gl_surface.h"
 #include "../core/i18n.h"
+#include "../core/filesystem/filesystem.h"
 // boost filesystem
 #include "boost/filesystem/convenience.hpp"
 namespace fs = boost::filesystem;
@@ -55,22 +56,20 @@ void cEato :: Init( void )
 	m_pos_z = 0.087f;
 	m_can_be_on_ground = 0;
 	Set_Rotation_Affects_Rect( 1 );
-	fire_resistant = 1;
+	m_fire_resistant = 1;
 
 	m_state = STA_STAY;
 	Set_Image_Dir( "enemy/eato/brown/" );
 	Set_Direction( DIR_UP_LEFT );
 
-	walk_count = static_cast<float>( rand() % 4 );
-
-	kill_sound = "enemy/eato/die.ogg";
-	kill_points = 150;
+	m_kill_sound = "enemy/eato/die.ogg";
+	m_kill_points = 150;
 }
 
 cEato *cEato :: Copy( void )
 {
 	cEato *eato = new cEato( m_start_pos_x, m_start_pos_y );
-	eato->Set_Image_Dir( img_dir );
+	eato->Set_Image_Dir( m_img_dir );
 	eato->Set_Direction( m_start_direction );
 
 	return eato;
@@ -81,7 +80,7 @@ void cEato :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// image directory
-	Set_Image_Dir( attributes.getValueAsString( "image_dir", img_dir ).c_str() );
+	Set_Image_Dir( attributes.getValueAsString( "image_dir", m_img_dir ).c_str() );
 	// direction
 	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( m_start_direction ) ).c_str() ) );
 }
@@ -97,7 +96,7 @@ void cEato :: Save_To_Stream( ofstream &file )
 	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(m_start_pos_x) << "\" />" << std::endl;
 	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(m_start_pos_y) << "\" />" << std::endl;
 	// image directory
-	file << "\t\t<Property name=\"image_dir\" value=\"" << img_dir << "\" />" << std::endl;
+	file << "\t\t<Property name=\"image_dir\" value=\"" << m_img_dir << "\" />" << std::endl;
 	// direction
 	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( m_start_direction ) << "\" />" << std::endl;
 
@@ -105,7 +104,7 @@ void cEato :: Save_To_Stream( ofstream &file )
 	file << "\t</enemy>" << std::endl;
 }
 
-void cEato :: Set_Image_Dir( const std::string &dir )
+void cEato :: Set_Image_Dir( std::string dir )
 {
 	if( dir.empty() )
 	{
@@ -113,29 +112,41 @@ void cEato :: Set_Image_Dir( const std::string &dir )
 	}
 
 	// remove pixmaps dir
-	if( img_dir.find( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) == 0 )
+	if( dir.find( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) == 0 )
 	{
-		img_dir.erase( 0, strlen( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) );
+		dir.erase( 0, strlen( DATA_DIR "/" GAME_PIXMAPS_DIR "/" ) );
 	}
 
-	// if directory does not exist
-	if( !fs::exists( fs::path( DATA_DIR "/" GAME_PIXMAPS_DIR "/" + dir, fs::native ) ) )
+	// add trailing slash if missing
+	if( *(dir.end() - 1) != '/' )
 	{
+		dir.insert( dir.length(), "/" );
+	}
+
+	// if not image directory
+	if( !File_Exists( DATA_DIR "/" GAME_PIXMAPS_DIR "/" + dir + "1.png" ) && !File_Exists( DATA_DIR "/" GAME_PIXMAPS_DIR "/" + dir + "1.settings" ) )
+	{
+		printf( "Warning : Eato image dir does not exist %s\n", dir.c_str() );
 		return;
 	}
 
-	img_dir = dir;
+	m_img_dir = dir;
 
 	// clear images
 	Clear_Images();
 	// set images
-	m_images.push_back( pVideo->Get_Surface( img_dir + "1.png" ) );
-	m_images.push_back( pVideo->Get_Surface( img_dir + "2.png" ) );
-	m_images.push_back( pVideo->Get_Surface( img_dir + "3.png" ) );
-	m_images.push_back( pVideo->Get_Surface( img_dir + "2.png" ) );
+	Add_Image( pVideo->Get_Surface( m_img_dir + "1.png" ) );
+	Add_Image( pVideo->Get_Surface( m_img_dir + "2.png" ) );
+	Add_Image( pVideo->Get_Surface( m_img_dir + "3.png" ) );
+	Add_Image( pVideo->Get_Surface( m_img_dir + "2.png" ) );
 	// set start image
 	Set_Image_Num( 0, 1 );
 
+	Set_Animation( 1 );
+	Set_Animation_Image_Range( 0, 3 );
+	Set_Time_All( 180, 1 );
+	Reset_Animation();
+
 	Create_Name();
 }
 
@@ -150,11 +161,11 @@ void cEato :: Set_Direction( const ObjectDirection dir )
 	cEnemy::Set_Direction( dir, 1 );
 
 	// clear
-	Set_Rotation( 0, 0, 0, 1 );
+	Set_Rotation( 0.0f, 0.0f, 0.0f, 1 );
 
 	if( m_start_direction == DIR_UP_LEFT )
 	{
-		Set_Rotation_Y( 180, 1 );
+		Set_Rotation_Y( 180.0f, 1 );
 	}
 	else if( m_start_direction == DIR_UP_RIGHT )
 	{
@@ -162,29 +173,29 @@ void cEato :: Set_Direction( const ObjectDirection dir )
 	}
 	else if( m_start_direction == DIR_LEFT_UP )
 	{
-		Set_Rotation_Z( 90, 1 );
-		Set_Rotation_X( 180, 1 );
+		Set_Rotation_Z( 90.0f, 1 );
+		Set_Rotation_X( 180.0f, 1 );
 	}
 	else if( m_start_direction == DIR_LEFT_DOWN )
 	{
-		Set_Rotation_Z( 90, 1 );
+		Set_Rotation_Z( 90.0f, 1 );
 	}
 	else if( m_start_direction == DIR_RIGHT_UP )
 	{
-		Set_Rotation_Z( 270, 1 );
+		Set_Rotation_Z( 270.0f, 1 );
 	}
 	else if( m_start_direction == DIR_RIGHT_DOWN )
 	{
-		Set_Rotation_Z( 270, 1 );
-		Set_Rotation_X( 180, 1 );
+		Set_Rotation_Z( 270.0f, 1 );
+		Set_Rotation_X( 180.0f, 1 );
 	}
 	else if( m_start_direction == DIR_DOWN_LEFT )
 	{
-		Set_Rotation_X( 180, 1 );
+		Set_Rotation_X( 180.0f, 1 );
 	}
 	else if( m_start_direction == DIR_DOWN_RIGHT )
 	{
-		Set_Rotation_Z( 180, 1 );
+		Set_Rotation_Z( 180.0f, 1 );
 	}
 
 	Create_Name();
@@ -194,7 +205,7 @@ void cEato :: DownGrade( bool force /* = 0 */ )
 {
 	Set_Dead( 1 );
 	m_massive_type = MASS_PASSIVE;
-	counter = 0;
+	m_counter = 0.0f;
 
 	if( !force )
 	{
@@ -203,22 +214,22 @@ void cEato :: DownGrade( bool force /* = 0 */ )
 		Generate_Hit_Animation( anim );
 
 		anim->Set_Scale( 0.8f );
-		anim->Set_Direction_Range( 0, 360 );
+		anim->Set_Direction_Range( 0.0f, 360.0f );
 		// add animation
 		pAnimation_Manager->Add( anim );
 	}
 	else
 	{
-		Set_Rotation_Z( 180 );
+		Set_Rotation_Z( 180.0f );
 	}
 }
 
-void cEato :: DieStep( void )
+void cEato :: Update_Dying( void )
 {
-	counter += pFramerate->speedfactor;
+	m_counter += pFramerate->m_speed_factor;
 
 	// default death
-	if( m_rot_z != 180 )
+	if( !Is_Float_Equal( m_rot_z, 180.0f ) )
 	{
 		Set_Active( 0 );
 	}
@@ -226,19 +237,19 @@ void cEato :: DieStep( void )
 	else
 	{
 		// a little bit upwards first
-		if( counter < 5 )
+		if( m_counter < 5.0f )
 		{
-			Move( 0, -5 );
+			Move( 0.0f, -5.0f );
 		}
 		// if not below the screen fall
 		else if( m_pos_y < game_res_h + m_col_rect.m_h )
 		{
-			Move( 0, 20 );
+			Move( 0.0f, 20.0f );
 		}
 		// if below disable
 		else
 		{
-			m_rot_z = 0;
+			m_rot_z = 0.0f;
 			Set_Active( 0 );
 		}
 	}
@@ -253,19 +264,12 @@ void cEato :: Update( void )
 		return;
 	}
 
-	walk_count += 0.2f * pFramerate->speedfactor;
-
-	if( walk_count >= 4 )
-	{
-		walk_count = 0;
-	}
-
-	Set_Image_Num( static_cast<int>(walk_count) );
+	Update_Animation();
 }
 
 bool cEato :: Is_Update_Valid( void )
 {
-	if( dead || m_freeze_counter )
+	if( m_dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -275,13 +279,25 @@ bool cEato :: Is_Update_Valid( void )
 
 Col_Valid_Type cEato :: Validate_Collision( cSprite *obj )
 {
-	if( obj->m_type == TYPE_PLAYER )
+	if( obj->m_massive_type == MASS_MASSIVE )
 	{
-		return COL_VTYPE_BLOCKING;
-	}
-	if( obj->m_type == TYPE_BALL )
-	{
-		return COL_VTYPE_BLOCKING;
+		switch( obj->m_type )
+		{
+			case TYPE_PLAYER:
+			{
+				return COL_VTYPE_BLOCKING;
+			}
+			case TYPE_BALL:
+			{
+				return COL_VTYPE_BLOCKING;
+			}
+			default:
+			{
+				break;
+			}
+		}
+
+		return COL_VTYPE_NOT_VALID;
 	}
 
 	return COL_VTYPE_NOT_VALID;
@@ -296,7 +312,7 @@ void cEato :: Handle_Collision_Player( cObjectCollision *collision )
 	}
 
 	// only if not invincible
-	if( pPlayer->invincible <= 0 )
+	if( pPlayer->invincible <= 0.0f )
 	{
 		// if player is big and not a bottom collision
 		if( pPlayer->maryo_type != MARYO_SMALL && ( collision->direction != DIR_BOTTOM ) )
@@ -335,7 +351,7 @@ void cEato :: Editor_Activate( void )
 	CEGUI::Editbox *editbox = static_cast<CEGUI::Editbox *>(wmgr.createWindow( "TaharezLook/Editbox", "editor_eato_image_dir" ));
 	Editor_Add( UTF8_("Image directory"), UTF8_("Directory containing the images"), editbox, 200 );
 
-	editbox->setText( img_dir.c_str() );
+	editbox->setText( m_img_dir.c_str() );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cEato::Editor_Image_Dir_Text_Changed, this ) );
 	// init
 	Editor_Init();
