@@ -54,35 +54,32 @@ void cGee :: Init( void  )
 	m_can_be_on_ground = 0;
 
 	m_state = STA_STAY;
-	dest_velx = 0;
-	dest_vely = 0;
+	m_speed_fly = 0.0f;
 	Set_Max_Distance( 400 );
-	always_fly = 0;
-	wait_time = 2;
-	fly_distance = 400;
+	m_always_fly = 0;
+	m_wait_time = 2.0f;
+	m_fly_distance = 400;
 
 	Set_Direction( DIR_HORIZONTAL );
-	color_type = COL_DEFAULT;
+	m_color_type = COL_DEFAULT;
 	Set_Color( COL_YELLOW );
 
-	kill_sound = "enemy/gee/die.ogg";
+	m_kill_sound = "enemy/gee/die.ogg";
 
-	walk_count = static_cast<float>( rand() % 4 );
-
-	wait_time_counter = 0;
-	fly_distance_counter = 0;
-	clouds_counter = 0;
+	m_wait_time_counter = 0.0f;
+	m_fly_distance_counter = 0.0f;
+	m_clouds_counter = 0.0f;
 }
 
 cGee *cGee :: Copy( void )
 {
 	cGee *gee = new cGee( m_start_pos_x, m_start_pos_y );
 	gee->Set_Direction( m_start_direction );
-	gee->Set_Max_Distance( max_distance );
-	gee->always_fly = always_fly;
-	gee->wait_time = wait_time;
-	gee->fly_distance = fly_distance;
-	gee->Set_Color( color_type );
+	gee->Set_Max_Distance( m_max_distance );
+	gee->m_always_fly = m_always_fly;
+	gee->m_wait_time = m_wait_time;
+	gee->m_fly_distance = m_fly_distance;
+	gee->Set_Color( m_color_type );
 
 	return gee;
 }
@@ -94,15 +91,15 @@ void cGee :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 	// direction
 	Set_Direction( Get_Direction_Id( attributes.getValueAsString( "direction", Get_Direction_Name( m_start_direction ) ).c_str() ) );
 	// max distance
-	Set_Max_Distance( attributes.getValueAsInteger( "max_distance", max_distance ) );
+	Set_Max_Distance( attributes.getValueAsInteger( "max_distance", m_max_distance ) );
 	// always fly
-	always_fly = attributes.getValueAsBool( "always_fly", always_fly );
+	m_always_fly = attributes.getValueAsBool( "always_fly", m_always_fly );
 	// wait time
-	wait_time = attributes.getValueAsFloat( "wait_time", wait_time );
+	m_wait_time = attributes.getValueAsFloat( "wait_time", m_wait_time );
 	// fly distance
-	fly_distance = attributes.getValueAsInteger( "fly_distance", fly_distance );
+	m_fly_distance = attributes.getValueAsInteger( "fly_distance", m_fly_distance );
 	// color
-	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
+	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( m_color_type ) ).c_str() )) );
 }
 
 void cGee :: Save_To_Stream( ofstream &file )
@@ -118,15 +115,15 @@ void cGee :: Save_To_Stream( ofstream &file )
 	// direction
 	file << "\t\t<Property name=\"direction\" value=\"" << Get_Direction_Name( m_start_direction ) << "\" />" << std::endl;
 	// max distance
-	file << "\t\t<Property name=\"max_distance\" value=\"" << static_cast<int>(max_distance) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"max_distance\" value=\"" << static_cast<int>(m_max_distance) << "\" />" << std::endl;
 	// always fly
-	file << "\t\t<Property name=\"always_fly\" value=\"" << always_fly << "\" />" << std::endl;
+	file << "\t\t<Property name=\"always_fly\" value=\"" << m_always_fly << "\" />" << std::endl;
 	// wait time
-	file << "\t\t<Property name=\"wait_time\" value=\"" << wait_time << "\" />" << std::endl;
+	file << "\t\t<Property name=\"wait_time\" value=\"" << m_wait_time << "\" />" << std::endl;
 	// fly distance
-	file << "\t\t<Property name=\"fly_distance\" value=\"" << static_cast<int>(fly_distance) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"fly_distance\" value=\"" << static_cast<int>(m_fly_distance) << "\" />" << std::endl;
 	// color
-	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( color_type ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( m_color_type ) << "\" />" << std::endl;
 
 	// end enemy
 	file << "\t</enemy>" << std::endl;
@@ -160,17 +157,20 @@ void cGee :: Set_Direction( const ObjectDirection dir )
 		cEnemy::Set_Direction( DIR_VERTICAL, 1 );
 	}
 
-	// horizontal
-	if( m_start_direction == DIR_HORIZONTAL )
+	if( m_state == STA_FLY )
 	{
-		dest_vely = 0;
-		dest_velx = 3;
-	}
-	// vertical
-	else
-	{
-		dest_vely = 3;
-		dest_velx = 0;
+		// horizontal
+		if( m_direction == DIR_HORIZONTAL )
+		{
+			m_velx = m_speed_fly;
+			m_vely = 0.0f;
+		}
+		// vertical
+		else
+		{
+			m_velx = 0.0f;
+			m_vely = m_speed_fly;
+		}
 	}
 
 	// update direction rotation
@@ -186,18 +186,18 @@ void cGee :: Set_Direction( const ObjectDirection dir )
 
 void cGee :: Set_Max_Distance( int nmax_distance )
 {
-	max_distance = nmax_distance;
+	m_max_distance = nmax_distance;
 
-	if( max_distance < 0 )
+	if( m_max_distance < 0 )
 	{
-		max_distance = 0;
+		m_max_distance = 0;
 	}
 }
 
 void cGee :: Set_Color( DefaultColor col )
 {
 	// already set
-	if( color_type == col )
+	if( m_color_type == col )
 	{
 		return;
 	}
@@ -205,66 +205,60 @@ void cGee :: Set_Color( DefaultColor col )
 	// clear old images
 	Clear_Images();
 
-	color_type = col;
+	m_color_type = col;
 
 	std::string filename_dir;
 
 	// Electro
-	if( color_type == COL_YELLOW )
+	if( m_color_type == COL_YELLOW )
 	{
 		filename_dir = "electro";
-		kill_points = 50;
 
-		fire_resistant = 0;
+		m_speed_fly = 6.0f;
+		m_kill_points = 50;
+
+		m_fire_resistant = 0;
 	}
 	// Lava
-	else if( color_type == COL_RED )
+	else if( m_color_type == COL_RED )
 	{
 		filename_dir = "lava";
 
-		if( dest_velx )
-		{
-			dest_velx = 4;
-		}
-		if( dest_vely )
-		{
-			dest_vely = 4;
-		}
-		kill_points = 100;
+		m_speed_fly = 8.0f;
+		m_kill_points = 100;
 
-		fire_resistant = 1;
+		m_fire_resistant = 1;
 	}
 	// Venom
-	else if( color_type == COL_GREEN )
+	else if( m_color_type == COL_GREEN )
 	{
 		filename_dir = "venom";
-		if( dest_velx )
-		{
-			dest_velx = 5;
-		}
-		if( dest_vely )
-		{
-			dest_vely = 5;
-		}
-		kill_points = 200;
 
-		fire_resistant = 0;
+		m_speed_fly = 10.0f;
+		m_kill_points = 200;
+
+		m_fire_resistant = 0;
 	}
 
 	Create_Name();
 
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/1.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/2.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/3.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/4.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/5.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/6.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/7.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/8.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/9.png" ) );
-	m_images.push_back( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/10.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/1.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/2.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/3.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/4.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/5.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/6.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/7.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/8.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/9.png" ) );
+	Add_Image( pVideo->Get_Surface( "enemy/gee/" + filename_dir + "/10.png" ) );
 
-	Set_Image_Num( 5, 1 );
+	Set_Image_Num( 0, 1 );
+
+	Set_Animation( 1 );
+	Set_Animation_Image_Range( 0, 9 );
+	Set_Time_All( 140, 1 );
+	Reset_Animation();
 }
 
 void cGee :: Turn_Around( ObjectDirection col_dir /* = DIR_UNDEFINED */ )
@@ -278,9 +272,9 @@ void cGee :: DownGrade( bool force /* = 0 */ )
 {
 	Set_Dead( 1 );
 	m_massive_type = MASS_PASSIVE;
-	counter = 0;
-	m_velx = 0;
-	m_vely = 0;
+	m_counter = 0.0f;
+	m_velx = 0.0f;
+	m_vely = 0.0f;
 
 	if( !force )
 	{
@@ -288,16 +282,16 @@ void cGee :: DownGrade( bool force /* = 0 */ )
 	}
 	else
 	{
-		Set_Rotation_Z( 180 );
+		Set_Rotation_Z( 180.0f );
 	}
 }
 
-void cGee :: DieStep( void )
+void cGee :: Update_Dying( void )
 {
-	counter += pFramerate->speedfactor;
+	m_counter += pFramerate->m_speed_factor;
 
 	// default death
-	if( m_rot_z != 180 )
+	if( !Is_Float_Equal( m_rot_z, 180.0f ) )
 	{
 		Set_Active( 0 );
 	}
@@ -305,24 +299,69 @@ void cGee :: DieStep( void )
 	else
 	{
 		// a little bit upwards first
-		if( counter < 5 )
+		if( m_counter < 5.0f )
 		{
-			Move( 0, -5 );
+			Move( 0.0f, -5.0f );
 		}
 		// if not below the screen fall
 		else if( m_pos_y < game_res_h + m_col_rect.m_h )
 		{
-			Move( 0, 20 );
+			Move( 0.0f, 20.0f );
 		}
 		// if below disable
 		else
 		{
-			m_rot_z = 0;
+			m_rot_z = 0.0f;
 			Set_Active( 0 );
 		}
 	}
 }
 
+void cGee :: Set_Moving_State( Moving_state new_state )
+{
+	if( new_state == m_state )
+	{
+		return;
+	}
+
+	if( new_state == STA_STAY )
+	{
+		m_fly_distance_counter = 0.0f;
+		m_velx = 0.0f;
+		m_vely = 0.0f;
+	}
+	else if( new_state == STA_FLY )
+	{
+		m_wait_time_counter = 0.0f;
+		// set velocity
+		if( m_start_direction == DIR_HORIZONTAL )
+		{
+			m_velx = m_speed_fly;
+			m_vely = 0.0f;
+			// randomize direction
+			if( rand() % 2 != 1 )
+			{
+				m_velx *= -1;
+			}
+		}
+		else
+		{
+			m_velx = 0.0f;
+			m_vely = m_speed_fly;
+			// randomize direction
+			if( rand() % 2 != 1 )
+			{
+				m_vely *= -1;
+			}
+		}
+
+		// update rotation
+		Update_Direction();
+	}
+
+	m_state = new_state;
+}
+
 void cGee :: Update( void )
 {
 	cEnemy::Update();
@@ -332,13 +371,15 @@ void cGee :: Update( void )
 		return;
 	}
 
+	Update_Animation();
+
 	// staying
 	if( m_state == STA_STAY )
 	{
-		wait_time_counter += pFramerate->speedfactor;
+		m_wait_time_counter += pFramerate->m_speed_factor;
 
 		// if wait time reached or always fly
-		if( wait_time_counter > wait_time * speedfactor_fps || always_fly )
+		if( m_wait_time_counter > m_wait_time * speedfactor_fps || m_always_fly )
 		{
 			Activate();
 		}
@@ -346,66 +387,39 @@ void cGee :: Update( void )
 	// moving
 	else
 	{
-		Col_Move( m_velx, m_vely, 0, 1, 0 );
-
 		// update fly distance counter
-		if( m_velx > 0 )
+		if( m_velx > 0.0f )
 		{
-			fly_distance_counter += m_velx * pFramerate->speedfactor;
+			m_fly_distance_counter += m_velx * pFramerate->m_speed_factor;
 		}
-		else if( m_velx < 0 )
+		else if( m_velx < 0.0f )
 		{
-			fly_distance_counter -= m_velx * pFramerate->speedfactor;
+			m_fly_distance_counter -= m_velx * pFramerate->m_speed_factor;
 		}
-		if( m_vely > 0 )
+		if( m_vely > 0.0f )
 		{
-			fly_distance_counter += m_vely * pFramerate->speedfactor;
+			m_fly_distance_counter += m_vely * pFramerate->m_speed_factor;
 		}
-		else if( m_vely < 0 )
+		else if( m_vely < 0.0f )
 		{
-			fly_distance_counter -= m_vely * pFramerate->speedfactor;
+			m_fly_distance_counter -= m_vely * pFramerate->m_speed_factor;
 		}
 
-		// check out of map screen
-		if( m_direction == DIR_DOWN )
-		{
-			// if below screen move back
-			if( m_rect.m_y + m_col_rect.m_h > game_res_h )
-			{
-				Turn_Around( DIR_DOWN );
-			}
-		}
-		// check out of max distance
-		if( !Check_Max_Distance() )
+		// walk_distance reached or if beyond max distance
+		if( ( !m_always_fly && m_fly_distance_counter > m_fly_distance ) || Is_At_Max_Distance() )
 		{
 			Stop();
 		}
 
 		// generate particle clouds
-		clouds_counter += pFramerate->speedfactor * 0.4f;
+		m_clouds_counter += pFramerate->m_speed_factor * 0.4f;
 
-		while( clouds_counter > 0 )
+		while( m_clouds_counter > 0.0f )
 		{
 			Generate_Particles();
-
-			clouds_counter--;
-		}
-
-		// walk_distance reached
-		if( !always_fly && fly_distance_counter > fly_distance )
-		{
-			Stop();
+			m_clouds_counter--;
 		}
 	}
-
-	walk_count += pFramerate->speedfactor * 0.3f;
-
-	if( walk_count >= 10 )
-	{
-		walk_count = 0;
-	}
-
-	Set_Image_Num( static_cast<int>(walk_count) );
 }
 
 void cGee :: Draw( cSurface_Request *request /* = NULL */ )
@@ -420,11 +434,11 @@ void cGee :: Draw( cSurface_Request *request /* = NULL */ )
 	{
 		if( m_start_direction == DIR_HORIZONTAL )
 		{
-			pVideo->Draw_Rect( m_start_pos_x - pActive_Camera->x - max_distance, m_start_pos_y + ( m_rect.m_h * 0.5f ) - 5 - pActive_Camera->y, m_col_rect.m_w + ( max_distance * 2.0f ), 10, m_pos_z - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( m_start_pos_x - pActive_Camera->x - m_max_distance, m_start_pos_y + ( m_rect.m_h * 0.5f ) - 5.0f - pActive_Camera->y, m_col_rect.m_w + ( m_max_distance * 2.0f ), 10.0f, m_pos_z - 0.000001f, &whitealpha128 );
 		}
 		else if( m_start_direction == DIR_VERTICAL )
 		{
-			pVideo->Draw_Rect( m_start_pos_x + ( m_rect.m_w * 0.5f ) - 5 - pActive_Camera->x, m_start_pos_y - pActive_Camera->y - max_distance, 10, m_col_rect.m_h + ( max_distance * 2.0f ), m_pos_z - 0.000001f, &whitealpha128 );
+			pVideo->Draw_Rect( m_start_pos_x + ( m_rect.m_w * 0.5f ) - 5.0f - pActive_Camera->x, m_start_pos_y - pActive_Camera->y - m_max_distance, 10.0f, m_col_rect.m_h + ( m_max_distance * 2.0f ), m_pos_z - 0.000001f, &whitealpha128 );
 		}
 	}
 
@@ -434,32 +448,15 @@ void cGee :: Draw( cSurface_Request *request /* = NULL */ )
 void cGee :: Activate( void )
 {
 	// if empty maximum distance or empty walk distance
-	if( !max_distance || !fly_distance )
+	if( !m_max_distance || !m_fly_distance )
 	{
 		return;
 	}
 
-	wait_time_counter = 0;
-	m_state = STA_WALK;
-
-	// set velocity
-	m_velx = dest_velx;
-	m_vely = dest_vely;
-	// random direction
-	if( rand() % 2 != 1 )
-	{
-		m_velx *= -1;
-	}
-	if( rand() % 2 != 1 )
-	{
-		m_vely *= -1;
-	}
-
-	// update rotation
-	Update_Direction();
+	Set_Moving_State( STA_FLY );
 
 	// check max distance
-	if( !Check_Max_Distance() )
+	if( Is_At_Max_Distance() )
 	{
 		// turn around also updates the direction rotation
 		Turn_Around();
@@ -473,10 +470,7 @@ void cGee :: Activate( void )
 
 void cGee :: Stop( void )
 {
-	fly_distance_counter = 0;
-	m_state = STA_STAY;
-	m_velx = 0;
-	m_vely = 0;
+	Set_Moving_State( STA_STAY );
 }
 
 void cGee :: Generate_Particles( unsigned int amount /* = 4 */ ) const
@@ -486,18 +480,18 @@ void cGee :: Generate_Particles( unsigned int amount /* = 4 */ ) const
 	anim->Set_Quota( amount );
 	anim->Set_Image( pVideo->Get_Surface( "animation/particles/cloud.png" ) );
 
-	if( !dead )
+	if( !m_dead )
 	{
-		anim->Set_Speed( 0, 0.5f );
+		anim->Set_Speed( 0.0f, 0.5f );
 
 		// direction
 		if( m_direction == DIR_LEFT )
 		{
-			anim->Set_Direction_Range( 90, 180 );
+			anim->Set_Direction_Range( 90.0f, 180.0f );
 		}
 		else
 		{
-			anim->Set_Direction_Range( 270, 180 );
+			anim->Set_Direction_Range( 270.0f, 180.0f );
 		}
 	}
 	else
@@ -508,61 +502,61 @@ void cGee :: Generate_Particles( unsigned int amount /* = 4 */ ) const
 	anim->Set_Scale( 0.5f, 0.3f );
 
 	// color
-	if( color_type == COL_YELLOW )
+	if( m_color_type == COL_YELLOW )
 	{
 		anim->Set_Color( yellow );
 	}
-	else if( color_type == COL_RED )
+	else if( m_color_type == COL_RED )
 	{
 		anim->Set_Color( lightred );
 	}
-	else if( color_type == COL_GREEN )
+	else if( m_color_type == COL_GREEN )
 	{
 		anim->Set_Color( lightgreen );
 	}
-	anim->Set_Time_to_Live( 2 );
+	anim->Set_Time_to_Live( 2.0f );
 	anim->Set_Fading_Alpha( 1 );
 	anim->Set_Blending( BLEND_ADD );
 	pAnimation_Manager->Add( anim );
 }
 
-bool cGee :: Check_Max_Distance( void ) const
+bool cGee :: Is_At_Max_Distance( void ) const
 {
 	if( m_direction == DIR_UP )
 	{
-		if( m_pos_y - m_start_pos_y < -max_distance )
+		if( m_pos_y - m_start_pos_y < -m_max_distance )
 		{
-			return 0;
+			return 1;
 		}
 	}
 	else if( m_direction == DIR_DOWN )
 	{
-		if( m_pos_y - m_start_pos_y > max_distance )
+		if( m_pos_y - m_start_pos_y > m_max_distance )
 		{
-			return 0;
+			return 1;
 		}
 	}
 	else if( m_direction == DIR_LEFT )
 	{
-		if( m_pos_x - m_start_pos_x < -max_distance )
+		if( m_pos_x - m_start_pos_x < -m_max_distance )
 		{
-			return 0;
+			return 1;
 		}
 	}
 	else if( m_direction == DIR_RIGHT )
 	{
-		if( m_pos_x - m_start_pos_x > max_distance )
+		if( m_pos_x - m_start_pos_x > m_max_distance )
 		{
-			return 0;
+			return 1;
 		}
 	}
 
-	return 1;
+	return 0;
 }
 
 bool cGee :: Is_Update_Valid( void )
 {
-	if( dead || m_freeze_counter )
+	if( m_dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -578,7 +572,7 @@ bool cGee :: Is_Draw_Valid( void )
 	if( editor_enabled )
 	{
 		// if active mouse object
-		if( pMouseCursor->active_object == this )
+		if( pMouseCursor->m_active_object == this )
 		{
 			return 1;
 		}
@@ -587,16 +581,27 @@ bool cGee :: Is_Draw_Valid( void )
 	return valid;
 }
 
-
 Col_Valid_Type cGee :: Validate_Collision( cSprite *obj )
 {
-	if( obj->m_type == TYPE_PLAYER )
+	if( obj->m_massive_type == MASS_MASSIVE )
 	{
-		return COL_VTYPE_INTERNAL;
-	}
-	if( obj->m_type == TYPE_BALL )
-	{
-		return COL_VTYPE_BLOCKING;
+		switch( obj->m_type )
+		{
+			case TYPE_PLAYER:
+			{
+				return COL_VTYPE_INTERNAL;
+			}
+			case TYPE_BALL:
+			{
+				return COL_VTYPE_INTERNAL;
+			}
+			default:
+			{
+				break;
+			}
+		}
+
+		return COL_VTYPE_NOT_VALID;
 	}
 
 	return COL_VTYPE_NOT_VALID;
@@ -612,12 +617,12 @@ void cGee :: Handle_Collision_Player( cObjectCollision *collision )
 
 	if( collision->direction == DIR_TOP && pPlayer->m_state != STA_FLY )
 	{
-		pAudio->Play_Sound( kill_sound );
+		pAudio->Play_Sound( m_kill_sound );
 
 		DownGrade();
 		pPlayer->Action_Jump( 1 );
 
-		pHud_Points->Add_Points( kill_points, pPlayer->m_pos_x, pPlayer->m_pos_y, "", static_cast<Uint8>(255), 1 );
+		pHud_Points->Add_Points( m_kill_points, pPlayer->m_pos_x, pPlayer->m_pos_y, "", static_cast<Uint8>(255), 1 );
 		pPlayer->Add_Kill_Multiplier();
 	}
 	else if( !pPlayer->invincible )
@@ -633,16 +638,20 @@ void cGee :: Handle_Collision_Player( cObjectCollision *collision )
 			}
 			else if( collision->direction == DIR_LEFT )
 			{
-				pPlayer->m_velx = -7;
+				pPlayer->m_velx = -7.0f;
 			}
 			else if( collision->direction == DIR_RIGHT )
 			{
-				pPlayer->m_velx = 7;
+				pPlayer->m_velx = 7.0f;
 			}
 		}
 
 		pPlayer->DownGrade_Player();
-		Turn_Around( collision->direction );
+
+		if( collision->direction == DIR_RIGHT || collision->direction == DIR_LEFT )
+		{
+			Turn_Around( collision->direction );
+		}
 	}
 }
 
@@ -671,7 +680,7 @@ void cGee :: Editor_Activate( void )
 	Editor_Add( UTF8_("Distance"), UTF8_("Movable distance"), editbox, 90 );
 
 	editbox->setValidationString( "^[+]?\\d*$" );
-	editbox->setText( int_to_string( max_distance ) );
+	editbox->setText( int_to_string( m_max_distance ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Max_Distance_Text_Changed, this ) );
 
 	// always fly
@@ -681,7 +690,7 @@ void cGee :: Editor_Activate( void )
 	combobox->addItem( new CEGUI::ListboxTextItem( UTF8_("Enabled") ) );
 	combobox->addItem( new CEGUI::ListboxTextItem( UTF8_("Disabled") ) );
 
-	if( always_fly )
+	if( m_always_fly )
 	{
 		combobox->setText( UTF8_("Enabled") );
 	}
@@ -697,7 +706,7 @@ void cGee :: Editor_Activate( void )
 	Editor_Add( UTF8_("Wait time"), UTF8_("Time to wait until moving again after a stop"), editbox, 90 );
 
 	editbox->setValidationString( "[+]?[0-9]*\\.?[0-9]*" );
-	editbox->setText( float_to_string( wait_time ) );
+	editbox->setText( float_to_string( m_wait_time ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Wait_Time_Text_Changed, this ) );
 
 	// fly distance
@@ -705,7 +714,7 @@ void cGee :: Editor_Activate( void )
 	Editor_Add( UTF8_("Fly distance"), UTF8_("The distance to move each time"), editbox, 90 );
 
 	editbox->setValidationString( "^[+]?\\d*$" );
-	editbox->setText( int_to_string( fly_distance ) );
+	editbox->setText( int_to_string( m_fly_distance ) );
 	editbox->subscribeEvent( CEGUI::Editbox::EventTextChanged, CEGUI::Event::Subscriber( &cGee::Editor_Fly_Distance_Text_Changed, this ) );
 
 	// init
@@ -739,11 +748,11 @@ bool cGee :: Editor_Always_Fly_Select( const CEGUI::EventArgs &event )
 
 	if( item->getText().compare( UTF8_("Enabled") ) == 0 )
 	{
-		always_fly = 1;
+		m_always_fly = 1;
 	}
 	else
 	{
-		always_fly = 0;
+		m_always_fly = 0;
 	}
 
 	return 1;
@@ -754,7 +763,7 @@ bool cGee :: Editor_Wait_Time_Text_Changed( const CEGUI::EventArgs &event )
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
 	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
-	wait_time = string_to_float( str_text );
+	m_wait_time = string_to_float( str_text );
 
 	return 1;
 }
@@ -764,7 +773,7 @@ bool cGee :: Editor_Fly_Distance_Text_Changed( const CEGUI::EventArgs &event )
 	const CEGUI::WindowEventArgs &windowEventArgs = static_cast<const CEGUI::WindowEventArgs&>( event );
 	std::string str_text = static_cast<CEGUI::Editbox *>( windowEventArgs.window )->getText().c_str();
 
-	fly_distance = string_to_int( str_text );
+	m_fly_distance = string_to_int( str_text );
 
 	return 1;
 }
@@ -773,15 +782,15 @@ void cGee :: Create_Name( void )
 {
 	m_name = "Gee";
 
-	if( color_type == COL_YELLOW )
+	if( m_color_type == COL_YELLOW )
 	{
 		m_name += "lectro";
 	}
-	else if( color_type == COL_RED )
+	else if( m_color_type == COL_RED )
 	{
 		m_name += "lava";
 	}
-	else if( color_type == COL_GREEN )
+	else if( m_color_type == COL_GREEN )
 	{
 		m_name += "venom";
 	}
