@@ -53,17 +53,18 @@ void cSpika :: Init( void )
 	m_type = TYPE_SPIKA;
 	m_pos_z = 0.09f;
 
-	color_type = COL_DEFAULT;
-	speed = 0;
-	detection_size = 0;
+	m_speed = 0.0f;
+	m_detection_size = 0.0f;
+	m_walk_count = 0.0f;
 
+	m_color_type = COL_DEFAULT;
 	Set_Color( COL_ORANGE );
 }
 
 cSpika *cSpika :: Copy( void )
 {
 	cSpika *spika = new cSpika( m_start_pos_x, m_start_pos_y );
-	spika->Set_Color( color_type );
+	spika->Set_Color( m_color_type );
 
 	return spika;
 }
@@ -73,7 +74,7 @@ void cSpika :: Create_From_Stream( CEGUI::XMLAttributes &attributes )
 	// position
 	Set_Pos( static_cast<float>(attributes.getValueAsInteger( "posx" )), static_cast<float>(attributes.getValueAsInteger( "posy" )), 1 );
 	// color
-	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( color_type ) ).c_str() )) );
+	Set_Color( static_cast<DefaultColor>(Get_Color_Id( attributes.getValueAsString( "color", Get_Color_Name( m_color_type ) ).c_str() )) );
 }
 
 void cSpika :: Save_To_Stream( ofstream &file )
@@ -87,7 +88,7 @@ void cSpika :: Save_To_Stream( ofstream &file )
 	file << "\t\t<Property name=\"posx\" value=\"" << static_cast<int>(m_start_pos_x) << "\" />" << std::endl;
 	file << "\t\t<Property name=\"posy\" value=\"" << static_cast<int>(m_start_pos_y) << "\" />" << std::endl;
 	// color
-	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( color_type ) << "\" />" << std::endl;
+	file << "\t\t<Property name=\"color\" value=\"" << Get_Color_Name( m_color_type ) << "\" />" << std::endl;
 
 	// end enemy
 	file << "\t</enemy>" << std::endl;
@@ -96,7 +97,7 @@ void cSpika :: Save_To_Stream( ofstream &file )
 void cSpika :: Set_Color( DefaultColor col )
 {
 	// already set
-	if( color_type == col )
+	if( m_color_type == col )
 	{
 		return;
 	}
@@ -104,56 +105,59 @@ void cSpika :: Set_Color( DefaultColor col )
 	// clear old images
 	Clear_Images();
 
-	color_type = col;
+	m_color_type = col;
 
-	if( color_type == COL_ORANGE )
+	if( m_color_type == COL_ORANGE )
 	{
-		m_images.push_back( pVideo->Get_Surface( "enemy/spika/orange.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/spika/orange.png" ) );
 
-		speed = 3;
-		detection_size = 160;
-		kill_points = 50;
+		m_speed = 3;
+		m_detection_size = 160.0f;
+		m_kill_points = 50;
 
-		fire_resistant = 0;
+		m_fire_resistant = 0;
+		m_ice_resistance = 0.0f;
 	}
-	else if( color_type == COL_GREEN )
+	else if( m_color_type == COL_GREEN )
 	{
-		m_images.push_back( pVideo->Get_Surface( "enemy/spika/green.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/spika/green.png" ) );
 
-		speed = 4;
-		detection_size = 220;
-		kill_points = 200;
+		m_speed = 4;
+		m_detection_size = 220.0f;
+		m_kill_points = 200;
 
-		fire_resistant = 0;
+		m_fire_resistant = 0;
+		m_ice_resistance = 0.1f;
 	}
-	else if( color_type == COL_GREY )
+	else if( m_color_type == COL_GREY )
 	{
-		m_images.push_back( pVideo->Get_Surface( "enemy/spika/grey.png" ) );
+		Add_Image( pVideo->Get_Surface( "enemy/spika/grey.png" ) );
 
-		speed = 7;
-		detection_size = 330;
-		kill_points = 500;
+		m_speed = 7;
+		m_detection_size = 330.0f;
+		m_kill_points = 500;
 
-		fire_resistant = 1;
+		m_fire_resistant = 1;
+		m_ice_resistance = 0.5f;
 	}
 	else
 	{
-		printf( "Error : Unknown Spika Color %d\n", color_type );
+		printf( "Error : Unknown Spika Color %d\n", m_color_type );
 	}
 
 	Set_Image_Num( 0, 1 );
 
 	m_name = "Spika ";
-	m_name += _(Get_Color_Name( color_type ).c_str());
+	m_name += _(Get_Color_Name( m_color_type ).c_str());
 }
 
 void cSpika :: DownGrade( bool force /* = 0 */ )
 {
 	Set_Dead( 1 );
 	m_massive_type = MASS_PASSIVE;
-	counter = 0;
-	m_velx = 0;
-	m_vely = 0;
+	m_counter = 0.0f;
+	m_velx = 0.0f;
+	m_vely = 0.0f;
 	Set_Scale_Directions( 1, 1, 1, 1 );
 
 	// default stomp death
@@ -164,33 +168,33 @@ void cSpika :: DownGrade( bool force /* = 0 */ )
 	// falling death
 	else
 	{
-		Set_Rotation_Z( 180 );
+		Set_Rotation_Z( 180.0f );
 	}
 }
 
-void cSpika :: DieStep( void )
+void cSpika :: Update_Dying( void )
 {
-	counter += pFramerate->speedfactor * 0.1f;
+	m_counter += pFramerate->m_speed_factor * 0.1f;
 
 	// falling death
 
 	// a little bit upwards first
-	if( counter < 0.3f )
+	if( m_counter < 0.3f )
 	{
-		Move( 0, -5 );
+		Move( 0.0f, -5.0f );
 	}
 	// if not below the screen fall
 	else if( m_pos_y < game_res_h + m_col_rect.m_h )
 	{
-		Move( 0, 20 );
+		Move( 0.0f, 20.0f );
 
-		Add_Scale( -pFramerate->speedfactor * 0.01f );
+		Add_Scale( -pFramerate->m_speed_factor * 0.01f );
 	}
 	// if below disable
 	else
 	{
-		m_rot_z = 0;
-		Set_Scale( 1 );
+		m_rot_z = 0.0f;
+		Set_Scale( 1.0f );
 		Set_Active( 0 );
 	}
 }
@@ -207,7 +211,7 @@ void cSpika :: Update( void )
 	// update rotation
 	if( m_velx != 0 )
 	{
-		Add_Rotation_Z( ( m_velx / ( m_image->m_w * 0.01f ) ) * pFramerate->speedfactor );
+		Add_Rotation_Z( ( m_velx / ( m_image->m_w * 0.01f ) ) * pFramerate->m_speed_factor );
 	}
 
 	// check for player
@@ -222,36 +226,36 @@ void cSpika :: Update( void )
 
 	GL_rect rect_right = rect_left;
 	// left
-	rect_left.m_x -= detection_size + ( m_col_rect.m_w / 2 );
-	rect_left.m_w += detection_size;
+	rect_left.m_x -= m_detection_size + ( m_col_rect.m_w / 2 );
+	rect_left.m_w += m_detection_size;
 	// right
 	rect_right.m_x -= m_col_rect.m_w / 2;
-	rect_right.m_w += detection_size;
+	rect_right.m_w += m_detection_size;
 
 
 	// if player is left
 	if( pPlayer->maryo_type != MARYO_GHOST && player_rect.Intersects( rect_left ) )
 	{
-		if( m_velx > -speed )
+		if( m_velx > -m_speed )
 		{
-			m_velx -= speed * 0.1f * pFramerate->speedfactor;
+			m_velx -= m_speed * 0.1f * pFramerate->m_speed_factor;
 
-			if( m_velx < -speed )
+			if( m_velx < -m_speed )
 			{
-				m_velx = -speed;
+				m_velx = -m_speed;
 			}
 		}
 	}
 	// if player is right
 	else if( pPlayer->maryo_type != MARYO_GHOST && player_rect.Intersects( rect_right ) )
 	{
-		if( m_velx < speed )
+		if( m_velx < m_speed )
 		{
-			m_velx += speed * 0.1f * pFramerate->speedfactor;
+			m_velx += m_speed * 0.1f * pFramerate->m_speed_factor;
 
-			if( m_velx > speed )
+			if( m_velx > m_speed )
 			{
-				m_velx = speed;
+				m_velx = m_speed;
 			}
 		}
 	}
@@ -259,15 +263,15 @@ void cSpika :: Update( void )
 	else
 	{
 		// slow down
-		m_velx -= (m_velx * 0.03f) * pFramerate->speedfactor;
+		m_velx -= (m_velx * 0.03f) * pFramerate->m_speed_factor;
 	}
 
 	// play walking sound based on speed
-	if( walk_count < m_rot_z - 30 || walk_count > m_rot_z + 30 )
+	if( m_walk_count < m_rot_z - 30.0f || m_walk_count > m_rot_z + 30.0f )
 	{
 		pAudio->Play_Sound( "enemy/spika/move.ogg" );
 
-		walk_count = m_rot_z;
+		m_walk_count = m_rot_z;
 	}
 
 	// gravity
@@ -276,7 +280,7 @@ void cSpika :: Update( void )
 
 bool cSpika :: Is_Update_Valid( void )
 {
-	if( dead || m_freeze_counter )
+	if( m_dead || m_freeze_counter )
 	{
 		return 0;
 	}
@@ -290,41 +294,48 @@ Col_Valid_Type cSpika :: Validate_Collision( cSprite *obj )
 	Col_Valid_Type basic_valid = Validate_Collision_Ghost( obj );
 
 	// found valid collision
-	if( basic_valid != COL_VTYPE_NO_GHOST )
+	if( basic_valid != COL_VTYPE_NOT_POSSIBLE )
 	{
 		return basic_valid;
 	}
 
 	if( obj->m_massive_type == MASS_MASSIVE )
 	{
-		if( obj->m_type == TYPE_ROKKO )
+		switch( obj->m_type )
 		{
-			return COL_VTYPE_NOT_VALID;
-		}
-		if( obj->m_type == TYPE_GEE )
-		{
-			return COL_VTYPE_NOT_VALID;
-		}
-		if( obj->m_type == TYPE_TURTLE_BOSS )
-		{
-			return COL_VTYPE_NOT_VALID;
-		}
-		if( obj->m_type == TYPE_FURBALL_BOSS )
-		{
-			return COL_VTYPE_NOT_VALID;
-		}
-		if( obj->m_type == TYPE_STATIC_ENEMY )
-		{
-			return COL_VTYPE_NOT_VALID;
+			case TYPE_ROKKO:
+			{
+				return COL_VTYPE_NOT_VALID;
+			}
+			case TYPE_GEE:
+			{
+				return COL_VTYPE_NOT_VALID;
+			}
+			case TYPE_TURTLE_BOSS:
+			{
+				return COL_VTYPE_NOT_VALID;
+			}
+			case TYPE_FURBALL_BOSS:
+			{
+				return COL_VTYPE_NOT_VALID;
+			}
+			case TYPE_STATIC_ENEMY:
+			{
+				return COL_VTYPE_NOT_VALID;
+			}
+			default:
+			{
+				break;
+			}
 		}
 
 		if( obj->m_sprite_array == ARRAY_ENEMY )
 		{
-			// if moving collide
-			if( m_velx != 0 )
+			// collide only if moving
+			if( !Is_Float_Equal( m_velx, 0.0f ) )
 			{
 				// if enemy is spika and more powerful
-				if( obj->m_type == TYPE_SPIKA && speed < static_cast<cSpika *>(obj)->speed )
+				if( obj->m_type == TYPE_SPIKA && m_speed < static_cast<cSpika *>(obj)->m_speed )
 				{
 					return COL_VTYPE_BLOCKING;
 				}
@@ -337,7 +348,7 @@ Col_Valid_Type cSpika :: Validate_Collision( cSprite *obj )
 
 		return COL_VTYPE_BLOCKING;
 	}
-	if( obj->m_massive_type == MASS_HALFMASSIVE )
+	else if( obj->m_massive_type == MASS_HALFMASSIVE )
 	{
 		// if moving downwards and the object is on bottom
 		if( m_vely >= 0 && Is_On_Top( obj ) )
@@ -355,7 +366,7 @@ void cSpika :: Handle_Collision_Player( cObjectCollision *collision )
 
 	if( collision->direction == DIR_LEFT || collision->direction == DIR_RIGHT )
 	{
-		m_velx = 0;
+		m_velx = 0.0f;
 	}
 }
 
@@ -367,27 +378,21 @@ void cSpika :: Handle_Collision_Enemy( cObjectCollision *collision )
 		return;
 	}
 
-	// only if moving
-	if( !m_velx )
-	{
-		return;
-	}
-
 	cEnemy *enemy = static_cast<cEnemy *>(pActive_Sprite_Manager->Get_Pointer( collision->number ));
 
 	// already dead
-	if( enemy->dead )
+	if( enemy->m_dead )
 	{
 		return;
 	}
 
-	// check spika power
+	// if spika
 	if( enemy->m_type == TYPE_SPIKA )
 	{
 		cSpika *spika = static_cast<cSpika *>(enemy);
 
 		// if colliding spika is more powerful
-		if( speed < spika->speed )
+		if( m_speed < spika->m_speed )
 		{
 			//enemy->Send_Collision( collision );
 			return;
@@ -401,26 +406,45 @@ void cSpika :: Handle_Collision_Enemy( cObjectCollision *collision )
 		cTurtleBoss *turtle_boss = static_cast<cTurtleBoss *>(enemy);
 
 		// downgrade until state change
-		for( int i = turtle_boss->hits; i < turtle_boss->max_hits; i++ )
+		for( int i = turtle_boss->m_hits; i < turtle_boss->m_max_hits; i++ )
 		{
 			turtle_boss->DownGrade();
 		}
 
-		// turtle kills spika
+		// boss kills spika
 		DownGrade( 1 );
 	}
 	// state change for furball boss
 	else if( enemy->m_type == TYPE_FURBALL_BOSS )
 	{
 		enemy->DownGrade();
-		// kills spika
+		// also hits us
+		DownGrade( 1 );
+	}
+	// enemies that also hit us
+	else if( ( enemy->m_type == TYPE_TURTLE && enemy->m_state == STA_RUN ) )
+	{
+		enemy->DownGrade( 1 );
+		// also hits us
+		DownGrade( 1 );
+	}
+	// enemies that only hit us
+	else if( enemy->m_type == TYPE_SPIKEBALL )
+	{
+		// hits us
 		DownGrade( 1 );
 	}
 	// kill enemy
 	else
 	{
-		pAudio->Play_Sound( enemy->kill_sound );
-		pHud_Points->Add_Points( enemy->kill_points, m_pos_x + m_image->m_w / 3, m_pos_y - 5, "", static_cast<Uint8>(255), 1 );
+		// only if moving
+		if( Is_Float_Equal( m_velx, 0.0f ) )
+		{
+			return;
+		}
+
+		pAudio->Play_Sound( enemy->m_kill_sound );
+		pHud_Points->Add_Points( enemy->m_kill_points, m_pos_x + m_image->m_w / 3, m_pos_y - 5, "", static_cast<Uint8>(255), 1 );
 		enemy->DownGrade( 1 );
 	}
 }
@@ -451,14 +475,9 @@ void cSpika :: Handle_Collision_Box( ObjectDirection cdirection, GL_rect *r2 )
 		{
 			m_velx -= 10;
 		}
-	}
-	// unsupported collision direction
-	else
-	{
-		return;
-	}
 
-	Reset_on_Ground();
+		Reset_On_Ground();
+	}
 }
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
