@@ -74,31 +74,31 @@ cMouseCursor :: cMouseCursor( void )
 {
 	m_type = TYPE_MOUSECURSOR;
 
-	clickcounter = 0;
+	m_click_counter = 0.0f;
 
-	mode_selection = 0;
-	selection_rect = GL_rect( 0, 0, 0, 0 );
+	m_selection_mode = 0;
+	m_selection_rect = GL_rect( 0, 0, 0, 0 );
 
-	mouse_object = new cSelectedObject();
-	active_object = NULL;
+	m_hovering_object = new cSelectedObject();
+	m_active_object = NULL;
 
-	mode_fastcopy = 0;
-	mover_mode = 0;
-	click_temp = NULL;
+	m_fastcopy_mode = 0;
+	m_mover_mode = 0;
+	m_last_clicked_object = NULL;
 
 	Reset_Keys();
 
-	SDL_GetMouseState( &x, &y );
+	SDL_GetMouseState( &m_x, &m_y );
 	// scale to the virtual game size
-	x = static_cast<int>( static_cast<float>(x) * global_downscalex );
-	y = static_cast<int>( static_cast<float>(y) * global_downscaley );
+	m_x = static_cast<int>( static_cast<float>(m_x) * global_downscalex );
+	m_y = static_cast<int>( static_cast<float>(m_y) * global_downscaley );
 }
 
 cMouseCursor :: ~cMouseCursor( void )
 {
 	Clear_Copy_Objects();
 	Clear_Selected_Objects();
-	delete mouse_object;
+	delete m_hovering_object;
 }
 
 void cMouseCursor :: Reset( bool clear_copy_buffer /* = 1 */ )
@@ -113,14 +113,14 @@ void cMouseCursor :: Reset( bool clear_copy_buffer /* = 1 */ )
 	Clear_Active_Object();
 
 	// change to default cursor
-	if( mover_mode )
+	if( m_mover_mode )
 	{
 		CEGUI::MouseCursor::getSingleton().setImage( "TaharezLook", "MouseArrow" );
 	}
 
-	mover_mode = 0;
-	mode_selection = 0;
-	mode_fastcopy = 0;
+	m_mover_mode = 0;
+	m_selection_mode = 0;
+	m_fastcopy_mode = 0;
 
 	Clear_Collisions();
 
@@ -133,9 +133,9 @@ void cMouseCursor :: Reset( bool clear_copy_buffer /* = 1 */ )
 
 void cMouseCursor :: Reset_Keys( void )
 {
-	left = 0;
-	right = 0;
-	middle = 0;
+	m_left = 0;
+	m_right = 0;
+	m_middle = 0;
 }
 
 bool cMouseCursor :: Handle_Event( SDL_Event *ev )
@@ -188,7 +188,7 @@ bool cMouseCursor :: Handle_Mouse_Down( Uint8 button )
 			{
 				return 1;
 			}
-			left = 1;
+			m_left = 1;
 			break;
 		}
 		case SDL_BUTTON_MIDDLE:
@@ -197,7 +197,7 @@ bool cMouseCursor :: Handle_Mouse_Down( Uint8 button )
 			{
 				return 1;
 			}
-			middle = 1;
+			m_middle = 1;
 			break;
 		}
 		case SDL_BUTTON_RIGHT:
@@ -206,7 +206,7 @@ bool cMouseCursor :: Handle_Mouse_Down( Uint8 button )
 			{
 				return 1;
 			}
-			right = 1;
+			m_right = 1;
 			break;
 		}
 		// mouse wheel
@@ -267,7 +267,7 @@ bool cMouseCursor :: Handle_Mouse_Up( Uint8 button )
 	{
 		case SDL_BUTTON_LEFT:
 		{
-			left = 0;
+			m_left = 0;
 			if( CEGUI::System::getSingleton().injectMouseButtonUp( CEGUI::LeftButton ) )
 			{
 				return 1;
@@ -276,7 +276,7 @@ bool cMouseCursor :: Handle_Mouse_Up( Uint8 button )
 		break;
 		case SDL_BUTTON_MIDDLE:
 		{
-			middle = 0;
+			m_middle = 0;
 			if( CEGUI::System::getSingleton().injectMouseButtonUp( CEGUI::MiddleButton ) )
 			{
 				return 1;
@@ -285,7 +285,7 @@ bool cMouseCursor :: Handle_Mouse_Up( Uint8 button )
 		break;
 		case SDL_BUTTON_RIGHT:
 		{
-			right = 0;
+			m_right = 0;
 			if( CEGUI::System::getSingleton().injectMouseButtonUp( CEGUI::RightButton ) )
 			{
 				return 1;
@@ -327,13 +327,11 @@ bool cMouseCursor :: Handle_Mouse_Up( Uint8 button )
 	return 0;
 }
 
-bool cMouseCursor :: Editor_Collsion_Check( float px /* = 0 */, float py /* = 0 */ )
+cObjectCollision *cMouseCursor :: Get_First_Editor_Collsion( float px /* = 0.0f */, float py /* = 0.0f */ )
 {
-	Clear_Collisions();
-
-	if( mover_mode )
+	if( m_mover_mode )
 	{
-		return 0;
+		return NULL;
 	}
 
 	// Get CEGUI Window containing the mouse
@@ -342,14 +340,14 @@ bool cMouseCursor :: Editor_Collsion_Check( float px /* = 0 */, float py /* = 0
 	// if mouse is over a blocking CEGUI window
 	if( mouse_window && !mouse_window->isMousePassThroughEnabled() )
 	{
-		return 0;
+		return NULL;
 	}
 
 	// mouse rect
 	GL_rect mouse_rect;
 
 	// use given posx
-	if( px != 0 )
+	if( !Is_Float_Equal( px, 0.0f ) )
 	{
 		mouse_rect.m_x = px;
 	}
@@ -359,7 +357,7 @@ bool cMouseCursor :: Editor_Collsion_Check( float px /* = 0 */, float py /* = 0
 	}
 
 	// use given posy
-	if( py != 0 )
+	if( !Is_Float_Equal( py, 0.0f ) )
 	{
 		mouse_rect.m_y = py;
 	}
@@ -368,19 +366,14 @@ bool cMouseCursor :: Editor_Collsion_Check( float px /* = 0 */, float py /* = 0
 		mouse_rect.m_y = m_pos_y;
 	}
 
-	mouse_rect.m_w = 1;
-	mouse_rect.m_h = 1;
-
-	if( Get_Collision( mouse_rect ) )
-	{
-		return 1;
-	}
+	mouse_rect.m_w = 1.0f;
+	mouse_rect.m_h = 1.0f;
 
 	// no collisions
-	return 0;
+	return Get_First_Mouse_Collision( mouse_rect );
 }
 
-bool cMouseCursor :: Get_Collision( const GL_rect &mouse_rect )
+cObjectCollision *cMouseCursor :: Get_First_Mouse_Collision( const GL_rect &mouse_rect )
 {
 	cSprite_List sprite_objects;
 	pActive_Sprite_Manager->Get_Objects_sorted( sprite_objects, 1, 1 );
@@ -390,7 +383,7 @@ bool cMouseCursor :: Get_Collision( const GL_rect &mouse_rect )
 	{
 		cSprite *obj = (*itr);
 
-		// don't check spawned/destroyed objects
+		// don't check spawned or destroyed objects
 		if( obj->m_spawned || obj->m_auto_destroy )
 		{
 			continue;
@@ -398,13 +391,11 @@ bool cMouseCursor :: Get_Collision( const GL_rect &mouse_rect )
 
 		if( mouse_rect.Intersects( obj->m_start_rect ) )
 		{
-			Add_Collision( Create_Collision_Object( this, obj, COL_VTYPE_INTERNAL ) );
-
-			return 1;
+			return Create_Collision_Object( this, obj, COL_VTYPE_INTERNAL );
 		}
 	}
 
-	return 0;
+	return NULL;
 }
 
 void cMouseCursor :: Update( void )
@@ -432,7 +423,7 @@ void cMouseCursor :: Draw( void )
 	if( Game_Mode == MODE_LEVEL || Game_Mode == MODE_OVERWORLD )
 	{
 		// draw if not in mover mode
-		if( !mover_mode )
+		if( !m_mover_mode )
 		{
 			Draw_Object_Rects();
 		}
@@ -456,19 +447,19 @@ void cMouseCursor :: Render( void ) const
 
 void cMouseCursor :: Update_Position( void )
 {
-	if( !mover_mode )
+	if( !m_mover_mode )
 	{
-		SDL_GetMouseState( &x, &y );
+		SDL_GetMouseState( &m_x, &m_y );
 		// scale to the virtual game size
-		x = static_cast<int>( static_cast<float>(x) * global_downscalex );
-		y = static_cast<int>( static_cast<float>(y) * global_downscaley );
+		m_x = static_cast<int>( static_cast<float>(m_x) * global_downscalex );
+		m_y = static_cast<int>( static_cast<float>(m_y) * global_downscaley );
 	}
 
 	if( editor_enabled )
 	{
-		if( !mover_mode )
+		if( !m_mover_mode )
 		{
-			Set_Pos( x + pActive_Camera->x, y + pActive_Camera->y, 1 );
+			Set_Pos( m_x + pActive_Camera->x, m_y + pActive_Camera->y, 1 );
 		}
 
 		Update_Mouse_Object();
@@ -476,88 +467,75 @@ void cMouseCursor :: Update_Position( void )
 	}
 	else
 	{
-		Set_Pos( static_cast<float>(x), static_cast<float>(y), 1 );
+		Set_Pos( static_cast<float>(m_x), static_cast<float>(m_y), 1 );
 	}
 }
 
 void cMouseCursor :: Update_Doubleclick( void )
 {
-	if( clickcounter )
+	if( m_click_counter )
 	{
-		clickcounter -= pFramerate->speedfactor;
+		m_click_counter -= pFramerate->m_speed_factor;
 
-		if( clickcounter < 0 )
+		if( m_click_counter < 0.0f )
 		{
-			clickcounter = 0;
+			m_click_counter = 0.0f;
 		}
 	}
 }
 
 void cMouseCursor :: Click( void )
 {
-	Editor_Collsion_Check();
-
-	if( mover_mode )
+	if( m_mover_mode )
 	{
 		return;
 	}
 
-	// no colliding sprite
-	if( !mouse_object->obj )
+	// if no hovering object
+	if( !m_hovering_object->obj )
 	{
-		cObjectCollision *col = Get_First_Collision();
-
-		// collision with an object
-		if( col )
+		// if shift is pressed
+		if( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] )
 		{
-			cSprite *col_obj = NULL;
+			cObjectCollision *col = Get_First_Editor_Collsion();
 
-			// player
-			if( col->m_array == ARRAY_PLAYER )
-			{
-				col_obj = static_cast<cSprite *>(pActive_Player);
-			}
-			// object manager object
-			else
-			{
-				col_obj = pActive_Sprite_Manager->Get_Pointer( col->number );
-			}
-
-			// if shift is pressed add object to the mouse objects
-			if( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] )
+			// collision with an object
+			if( col )
 			{
 				// add object
-				if( !Add_Selected_Object( col_obj, 1 ) )
+				if( !Add_Selected_Object( col->obj, 1 ) )
 				{
 					// if already added remove it
-					Remove_Selected_Object( col_obj );
+					Remove_Selected_Object( col->obj );
 				}
+
+				delete col;
 			}
 		}
 
 		Start_Selection();
-		clickcounter = 0;
+		m_click_counter = 0.0f;
 		return;
 	}
 
-	if( clickcounter > 0 )
+	if( m_click_counter > 0.0f )
 	{
 		// if last clicked object was the same
-		if( click_temp == mouse_object->obj )
+		if( m_last_clicked_object == m_hovering_object->obj )
 		{
 			Double_Click();
 		}
 		else
 		{
-			clickcounter = 0;
+			m_click_counter = 0.0f;
 		}
 	}
 	else
 	{
 		// double click counter
-		clickcounter = speedfactor_fps * 0.3f;
+		m_click_counter = speedfactor_fps * 0.3f;
 		// save last clicked object
-		click_temp = mouse_object->obj;
+		m_last_clicked_object = m_hovering_object->obj;
 	}
 }
 
@@ -568,57 +546,63 @@ void cMouseCursor :: Double_Click( bool activate /* = 1 */ )
 	// add new
 	if( activate )
 	{
-		Set_Active_Object( mouse_object->obj );
+		Set_Active_Object( m_hovering_object->obj );
 	}
 
-	clickcounter = 0;
+	m_click_counter = 0.0f;
 }
 
 void cMouseCursor :: Set_Mouse_Object( cSprite *sprite )
 {
 	// return if mouse object is the same or in mouse selection mode
-	if( mouse_object->obj == sprite || ( sprite && ( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] || mode_selection ) ) )
+	if( m_hovering_object->obj == sprite || ( sprite && ( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] || m_selection_mode ) ) )
 	{
 		return;
 	}
 
-	// remove old mouse_object from selected objects
-	if( mouse_object->obj )
+	// remove old m_hovering_object from selected objects
+	if( m_hovering_object->obj )
 	{
-		Remove_Selected_Object( mouse_object->obj, 1 );
+		Remove_Selected_Object( m_hovering_object->obj, 1 );
 	}
 
 	// set new mouse object
-	mouse_object->obj = sprite;
+	m_hovering_object->obj = sprite;
 	// add new mouse object to selected objects
 	Add_Selected_Object( sprite );
+
+	if( !sprite )
+	{
+		m_hovering_object->mouse_w = 0;
+		m_hovering_object->mouse_h = 0;
+	}
 }
 
 void cMouseCursor :: Update_Mouse_Object( void )
 {
-	if( ( !editor_enabled ) || !mouse_object->obj || ( mover_mode && ( Game_Mode == MODE_LEVEL || Game_Mode == MODE_OVERWORLD ) ) )
+	if( !editor_enabled || !m_hovering_object->obj || ( m_mover_mode && ( Game_Mode == MODE_LEVEL || Game_Mode == MODE_OVERWORLD ) ) )
 	{
 		return;
 	}
 
-	// left mouse is pressed and no shift
-	if( left )
+	// left mouse is pressed
+	if( m_left )
 	{
 		// set new position
-		mouse_object->obj->Set_Pos( static_cast<float>( static_cast<int>(m_pos_x) - mouse_object->mouse_w ), static_cast<float>( static_cast<int>(m_pos_y) - mouse_object->mouse_h ), 1 );
+		m_hovering_object->obj->Set_Pos( static_cast<float>( static_cast<int>(m_pos_x) - m_hovering_object->mouse_w ), static_cast<float>( static_cast<int>(m_pos_y) - m_hovering_object->mouse_h ), 1 );
 
 		// update object settings position
-		if( active_object && active_object == mouse_object->obj )
+		if( m_active_object && m_active_object == m_hovering_object->obj )
 		{
-			active_object->Editor_Position_Update();
+			m_active_object->Editor_Position_Update();
 		}
 	}
 	// left mouse is not pressed
 	else
 	{
 		// update mouse object positioning mouse width and height
-		mouse_object->mouse_w = static_cast<int>(m_pos_x) - static_cast<int>(mouse_object->obj->m_start_pos_x);
-		mouse_object->mouse_h = static_cast<int>(m_pos_y) - static_cast<int>(mouse_object->obj->m_start_pos_y);
+		m_hovering_object->mouse_w = static_cast<int>(m_pos_x) - static_cast<int>(m_hovering_object->obj->m_start_pos_x);
+		m_hovering_object->mouse_h = static_cast<int>(m_pos_y) - static_cast<int>(m_hovering_object->obj->m_start_pos_y);
 	}
 }
 
@@ -635,7 +619,7 @@ void cMouseCursor :: Add_Copy_Object( cSprite *sprite )
 	}
 
 	// check if not already added
-	for( CopyObjectList::iterator itr = copy_objects.begin(), itr_end = copy_objects.end(); itr != itr_end; ++itr )
+	for( CopyObjectList::iterator itr = m_copy_objects.begin(), itr_end = m_copy_objects.end(); itr != itr_end; ++itr )
 	{
 		if( (*itr)->obj == sprite )
 		{
@@ -654,7 +638,7 @@ void cMouseCursor :: Add_Copy_Object( cSprite *sprite )
 	// insert object
 	cCopyObject *copy_object = new cCopyObject();
 	copy_object->obj = copy;
-	copy_objects.push_back( copy_object );
+	m_copy_objects.push_back( copy_object );
 }
 
 void cMouseCursor :: Add_Copy_Objects( cSprite_List &spritelist )
@@ -680,13 +664,13 @@ bool cMouseCursor :: Remove_Copy_Object( const cSprite *sprite )
 		return 0;
 	}
 
-	for( CopyObjectList::iterator itr = copy_objects.begin(), itr_end = copy_objects.end(); itr != itr_end; ++itr )
+	for( CopyObjectList::iterator itr = m_copy_objects.begin(), itr_end = m_copy_objects.end(); itr != itr_end; ++itr )
 	{
 		cCopyObject *copy_obj = (*itr);
 
 		if( copy_obj->obj == sprite )
 		{
-			copy_objects.erase( itr );
+			m_copy_objects.erase( itr );
 			delete copy_obj;
 			
 			return 1;
@@ -698,28 +682,28 @@ bool cMouseCursor :: Remove_Copy_Object( const cSprite *sprite )
 
 void cMouseCursor :: Clear_Copy_Objects( void )
 {
-	for( CopyObjectList::iterator itr = copy_objects.begin(), itr_end = copy_objects.end(); itr != itr_end; ++itr )
+	for( CopyObjectList::iterator itr = m_copy_objects.begin(), itr_end = m_copy_objects.end(); itr != itr_end; ++itr )
 	{
 		delete *itr;
 	}
 
-	copy_objects.clear();
+	m_copy_objects.clear();
 }
 
 GL_Vector cMouseCursor :: Get_Copy_Object_Base( float px, float py )
 {
 	GL_Vector vec = GL_Vector();
 
-	if( copy_objects.empty() )
+	if( m_copy_objects.empty() )
 	{
 		return vec;
 	}
 
 	// set a base
-	float base_x = copy_objects[0]->obj->m_pos_x;
-	float base_y = copy_objects[0]->obj->m_pos_y;
+	float base_x = m_copy_objects[0]->obj->m_pos_x;
+	float base_y = m_copy_objects[0]->obj->m_pos_y;
 
-	for( CopyObjectList::iterator itr = copy_objects.begin(), itr_end = copy_objects.end(); itr != itr_end; ++itr )
+	for( CopyObjectList::iterator itr = m_copy_objects.begin(), itr_end = m_copy_objects.end(); itr != itr_end; ++itr )
 	{
 		cCopyObject *copy_obj = (*itr);
 
@@ -739,14 +723,14 @@ GL_Vector cMouseCursor :: Get_Copy_Object_Base( float px, float py )
 
 void cMouseCursor :: Paste_Copy_Objects( float px, float py )
 {
-	if( copy_objects.empty() )
+	if( m_copy_objects.empty() )
 	{
 		return;
 	}
 
 	cSprite_List new_objects;
 
-	for( CopyObjectList::iterator itr = copy_objects.begin(), itr_end = copy_objects.end(); itr != itr_end; ++itr )
+	for( CopyObjectList::iterator itr = m_copy_objects.begin(), itr_end = m_copy_objects.end(); itr != itr_end; ++itr )
 	{
 		cCopyObject *copy_obj = (*itr);
 
@@ -762,10 +746,10 @@ void cMouseCursor :: Paste_Copy_Objects( float px, float py )
 		}
 	}
 
-	if( !copy_objects.empty() )
+	if( !m_copy_objects.empty() )
 	{
-		mouse_object->mouse_h = static_cast<int>( copy_objects[0]->obj->m_col_rect.m_h / 2 );
-		mouse_object->mouse_w = static_cast<int>( copy_objects[0]->obj->m_col_rect.m_w / 2 );
+		m_hovering_object->mouse_h = static_cast<int>( m_copy_objects[0]->obj->m_col_rect.m_h / 2 );
+		m_hovering_object->mouse_w = static_cast<int>( m_copy_objects[0]->obj->m_col_rect.m_w / 2 );
 	}
 
 	// pasted objects are selected
@@ -781,7 +765,7 @@ bool cMouseCursor :: Add_Selected_Object( cSprite *sprite, bool from_user /* = 0
 	}
 
 	// check if not already added
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *sel_obj = (*itr);
 
@@ -802,7 +786,7 @@ bool cMouseCursor :: Add_Selected_Object( cSprite *sprite, bool from_user /* = 0
 	cSelectedObject *selected_object = new cSelectedObject();
 	selected_object->obj = sprite;
 	selected_object->user = from_user;
-	selected_objects.push_back( selected_object );
+	m_selected_objects.push_back( selected_object );
 
 	return 1;
 }
@@ -830,7 +814,7 @@ bool cMouseCursor :: Remove_Selected_Object( const cSprite *sprite, bool no_user
 		return 0;
 	}
 
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *sel_obj = (*itr);
 
@@ -842,7 +826,7 @@ bool cMouseCursor :: Remove_Selected_Object( const cSprite *sprite, bool no_user
 				return 0;
 			}
 
-			selected_objects.erase( itr );
+			m_selected_objects.erase( itr );
 			delete sel_obj;
 			
 			return 1;
@@ -856,7 +840,7 @@ cSprite_List cMouseCursor :: Get_Selected_Objects( void )
 {
 	cSprite_List spritelist;
 
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *object = (*itr);
 
@@ -868,27 +852,27 @@ cSprite_List cMouseCursor :: Get_Selected_Objects( void )
 
 void cMouseCursor :: Clear_Selected_Objects( void )
 {
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		delete *itr;
 	}
 
-	selected_objects.clear();
+	m_selected_objects.clear();
 }
 
 void cMouseCursor :: Update_Selected_Objects( void )
 {
-	if( !editor_enabled || ( mover_mode && ( Game_Mode == MODE_LEVEL || Game_Mode == MODE_OVERWORLD ) ) )
+	if( !editor_enabled || ( m_mover_mode && ( Game_Mode == MODE_LEVEL || Game_Mode == MODE_OVERWORLD ) ) )
 	{
 		return;
 	}
 
 	// update selected objects positioning mouse width and height
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *sel_obj = (*itr);
 
-		if( !left || mode_selection )
+		if( !m_left || m_selection_mode )
 		{
 			sel_obj->mouse_w = static_cast<int>(m_pos_x) - static_cast<int>(sel_obj->obj->m_start_pos_x);
 			sel_obj->mouse_h = static_cast<int>(m_pos_y) - static_cast<int>(sel_obj->obj->m_start_pos_y);
@@ -896,25 +880,25 @@ void cMouseCursor :: Update_Selected_Objects( void )
 	}
 
 	// if a user selected object is not active
-	if( !Is_Selected_Object( mouse_object->obj, 1 ) )
+	if( !Is_Selected_Object( m_hovering_object->obj, 1 ) )
 	{
 		return;
 	}
 
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *sel_obj = (*itr);
 
 		// left mouse is pressed
-		if( left )
+		if( m_left )
 		{
 			// set new position
 			sel_obj->obj->Set_Pos( static_cast<float>(static_cast<int>(m_pos_x) - sel_obj->mouse_w), static_cast<float>(static_cast<int>(m_pos_y) - sel_obj->mouse_h), 1 );
 
 			// update object settings position
-			if( active_object && active_object == sel_obj->obj )
+			if( m_active_object && m_active_object == sel_obj->obj )
 			{
-				active_object->Editor_Position_Update();
+				m_active_object->Editor_Position_Update();
 			}
 		}
 	}
@@ -927,7 +911,7 @@ bool cMouseCursor :: Is_Selected_Object( const cSprite *sprite, bool only_user /
 		return 0;
 	}
 
-	for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+	for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 	{
 		cSelectedObject *sel_obj = (*itr);
 
@@ -949,9 +933,9 @@ bool cMouseCursor :: Is_Selected_Object( const cSprite *sprite, bool only_user /
 
 void cMouseCursor :: Delete_Selected_Objects( void )
 {
-	for( int i = selected_objects.size() - 1; i >= 0; i-- )
+	for( int i = m_selected_objects.size() - 1; i >= 0; i-- )
 	{
-		Delete( selected_objects[i]->obj );
+		Delete( m_selected_objects[i]->obj );
 	}
 
 	Clear_Selected_Objects();
@@ -959,7 +943,7 @@ void cMouseCursor :: Delete_Selected_Objects( void )
 
 unsigned int cMouseCursor :: Get_Selected_Object_Size( void ) const
 {
-	return selected_objects.size();
+	return m_selected_objects.size();
 }
 
 void cMouseCursor :: Set_Active_Object( cSprite *sprite )
@@ -969,20 +953,20 @@ void cMouseCursor :: Set_Active_Object( cSprite *sprite )
 
 	if( sprite )
 	{
-		active_object = sprite;
-		active_object->Editor_Activate();
+		m_active_object = sprite;
+		m_active_object->Editor_Activate();
 	}
 }
 
 void cMouseCursor :: Clear_Active_Object( void )
 {
-	if( !active_object )
+	if( !m_active_object )
 	{
 		return;
 	}
 
-	active_object->Editor_Deactivate();
-	active_object = NULL;
+	m_active_object->Editor_Deactivate();
+	m_active_object = NULL;
 }
 
 cSprite *cMouseCursor :: Copy( cSprite *ncopy_object, float px, float py ) const
@@ -1039,7 +1023,7 @@ void cMouseCursor :: Delete( cSprite *sprite )
 	}
 
 	// deactivate active object
-	if( active_object == sprite )
+	if( m_active_object == sprite )
 	{
 		Double_Click( 0 );
 	}
@@ -1069,21 +1053,21 @@ void cMouseCursor :: Draw_Object_Rects( void )
 	// current object color
 	Color obj_color = white;
 
-	if( !left && mouse_object->obj )
+	if( !m_left && m_hovering_object->obj )
 	{
-		hover_rect.m_x = mouse_object->obj->m_start_pos_x - pActive_Camera->x;
-		hover_rect.m_y = mouse_object->obj->m_start_pos_y - pActive_Camera->y;
-		hover_rect.m_w = mouse_object->obj->m_start_rect.m_w;
-		hover_rect.m_h = mouse_object->obj->m_start_rect.m_h;
+		hover_rect.m_x = m_hovering_object->obj->m_start_pos_x - pActive_Camera->x;
+		hover_rect.m_y = m_hovering_object->obj->m_start_pos_y - pActive_Camera->y;
+		hover_rect.m_w = m_hovering_object->obj->m_start_rect.m_w;
+		hover_rect.m_h = m_hovering_object->obj->m_start_rect.m_h;
 
 		// get object color
-		obj_color = Get_Massive_Type_Color( mouse_object->obj->m_massive_type );
+		obj_color = Get_Massive_Type_Color( m_hovering_object->obj->m_massive_type );
 
 		// create request
 		cRect_Request *request = new cRect_Request();
 		pVideo->Draw_Rect( &hover_rect, 0.6f, &obj_color, request );
 
-		if( mode_fastcopy )
+		if( m_fastcopy_mode )
 		{
 			request->color.alpha = 64;
 		}
@@ -1100,16 +1084,16 @@ void cMouseCursor :: Draw_Object_Rects( void )
 
 
 	// draw selected objects if not left mouse is pressed, shift selection or mouse selection
-	if( !left || ( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] ) || mode_selection )
+	if( !m_left || ( pKeyboard->keys[SDLK_RSHIFT] || pKeyboard->keys[SDLK_LSHIFT] ) || m_selection_mode )
 	{
 		obj_color = white;
 
-		for( SelectedObjectList::iterator itr = selected_objects.begin(), itr_end = selected_objects.end(); itr != itr_end; ++itr )
+		for( SelectedObjectList::iterator itr = m_selected_objects.begin(), itr_end = m_selected_objects.end(); itr != itr_end; ++itr )
 		{
 			cSprite *object = (*itr)->obj;
 
 			// check if visible on screen or mouse object
-			if( !object->Is_Visible_On_Screen() || object == mouse_object->obj )
+			if( !object->Is_Visible_On_Screen() || object == m_hovering_object->obj )
 			{
 				continue;
 			}
@@ -1157,53 +1141,53 @@ void cMouseCursor :: Draw_Object_Rects( void )
 void cMouseCursor :: Start_Selection( void )
 {
 	Clear_Mouse_Object();
-	mode_selection = 1;
-	selection_rect.m_x = x + pActive_Camera->x;
-	selection_rect.m_y = y + pActive_Camera->y;
+	m_selection_mode = 1;
+	m_selection_rect.m_x = m_x + pActive_Camera->x;
+	m_selection_rect.m_y = m_y + pActive_Camera->y;
 }
 
 void cMouseCursor :: End_Selection( void )
 {
-	mode_selection = 0;
+	m_selection_mode = 0;
 
 	Update_Position();
 }
 
 void cMouseCursor :: Update_Selection( void )
 {
-	if( !mode_selection )
+	if( !m_selection_mode )
 	{
 		return;
 	}
 
-	selection_rect.m_w = x - selection_rect.m_x + pActive_Camera->x;
-	selection_rect.m_h = y - selection_rect.m_y + pActive_Camera->y;
+	m_selection_rect.m_w = m_x - m_selection_rect.m_x + pActive_Camera->x;
+	m_selection_rect.m_h = m_y - m_selection_rect.m_y + pActive_Camera->y;
 
 	// create collision checking rect
-	GL_rect rect = GL_rect( selection_rect.m_x, selection_rect.m_y, 0, 0 );
+	GL_rect rect = GL_rect( m_selection_rect.m_x, m_selection_rect.m_y, 0, 0 );
 
 	// negative to positive
-	if( selection_rect.m_w < 0 )
+	if( m_selection_rect.m_w < 0 )
 	{
-		rect.m_x = selection_rect.m_x + selection_rect.m_w;
-		rect.m_w = -selection_rect.m_w;
+		rect.m_x = m_selection_rect.m_x + m_selection_rect.m_w;
+		rect.m_w = -m_selection_rect.m_w;
 	}
 	// positive
 	else
 	{
-		rect.m_w = selection_rect.m_w;
+		rect.m_w = m_selection_rect.m_w;
 	}
 
 	// negative to positive
-	if( selection_rect.m_h < 0 )
+	if( m_selection_rect.m_h < 0 )
 	{
-		rect.m_y = selection_rect.m_y + selection_rect.m_h;
-		rect.m_h = -selection_rect.m_h;
+		rect.m_y = m_selection_rect.m_y + m_selection_rect.m_h;
+		rect.m_h = -m_selection_rect.m_h;
 	}
 	// positive
 	else
 	{
-		rect.m_h = selection_rect.m_h;
+		rect.m_h = m_selection_rect.m_h;
 	}
 
 	// if rect is below minimum
@@ -1245,7 +1229,7 @@ void cMouseCursor :: Update_Selection( void )
 
 	// ## inner rect
 	cRect_Request *rect_request = new cRect_Request();
-	pVideo->Draw_Rect( selection_rect.m_x - pActive_Camera->x + 0.5f, selection_rect.m_y - pActive_Camera->y + 0.5f, selection_rect.m_w, selection_rect.m_h, 0.509f, &white, rect_request );
+	pVideo->Draw_Rect( m_selection_rect.m_x - pActive_Camera->x + 0.5f, m_selection_rect.m_y - pActive_Camera->y + 0.5f, m_selection_rect.m_w, m_selection_rect.m_h, 0.509f, &white, rect_request );
 
 	// not filled
 	rect_request->filled = 0;
@@ -1258,7 +1242,7 @@ void cMouseCursor :: Update_Selection( void )
 	// ## outer rect
 	// create request
 	rect_request = new cRect_Request();
-	pVideo->Draw_Rect( selection_rect.m_x - pActive_Camera->x, selection_rect.m_y - pActive_Camera->y, selection_rect.m_w, selection_rect.m_h, 0.51f, &lightblue, rect_request );
+	pVideo->Draw_Rect( m_selection_rect.m_x - pActive_Camera->x, m_selection_rect.m_y - pActive_Camera->y, m_selection_rect.m_w, m_selection_rect.m_h, 0.51f, &lightblue, rect_request );
 
 	// not filled
 	rect_request->filled = 0;
@@ -1269,9 +1253,9 @@ void cMouseCursor :: Update_Selection( void )
 
 void cMouseCursor :: Toggle_Mover_Mode( void )
 {
-	mover_mode = !mover_mode;
+	m_mover_mode = !m_mover_mode;
 
-	if( mover_mode )
+	if( m_mover_mode )
 	{
 		CEGUI::MouseCursor::getSingleton().setImage( "TaharezLook", "MouseMoveCursor" );
 	}
@@ -1283,7 +1267,7 @@ void cMouseCursor :: Toggle_Mover_Mode( void )
 
 void cMouseCursor :: Mover_Update( Sint16 move_x, Sint16 move_y )
 {
-	if( !mover_mode )
+	if( !m_mover_mode )
 	{
 		return;
 	}
@@ -1291,7 +1275,7 @@ void cMouseCursor :: Mover_Update( Sint16 move_x, Sint16 move_y )
 	// mouse moves the camera
 	pActive_Camera->Move( move_x, move_y );
 	// keep mouse at it's position
-	SDL_WarpMouse( static_cast<Uint16>(x * global_upscalex), static_cast<Uint16>(y * global_upscaley) );
+	SDL_WarpMouse( static_cast<Uint16>(m_x * global_upscalex), static_cast<Uint16>(m_y * global_upscaley) );
 
 	SDL_Event inEvent;
 	SDL_PeepEvents( &inEvent, 1, SDL_GETEVENT, SDL_MOUSEMOTIONMASK );
@@ -1304,13 +1288,13 @@ void cMouseCursor :: Mover_Update( Sint16 move_x, Sint16 move_y )
 			{
 				if( inEvent.button.button == 2 )
 				{
-					mover_mode = 0;
+					m_mover_mode = 0;
 				}
 				break;
 			}
 			case SDL_KEYDOWN:
 			{
-				mover_mode = 0;
+				m_mover_mode = 0;
 				pKeyboard->Key_Down( inEvent.key.keysym.sym );
 				break;
 			}
@@ -1330,163 +1314,19 @@ void cMouseCursor :: Editor_Update( void )
 		return;
 	}
 
-	bool is_col = Editor_Collsion_Check();
-	cObjectCollision *col = Get_First_Collision();
+	cObjectCollision *col = Get_First_Editor_Collsion();
 
-	// valid object
-	if( is_col && col )
+	// if no collision
+	if( !col )
 	{
-		// get colliding object
-		cSprite *obj = NULL;
-
-		// player
-		if( col->m_array == ARRAY_PLAYER )
-		{
-			obj = static_cast<cSprite *>(pActive_Player);
-		}
-		// object manager object
-		else
-		{
-			obj = pActive_Sprite_Manager->Get_Pointer( col->number );
-		}
-
-		// mouse object type string
-		std::string type_name;
-
-		// set object data
-		if( obj )
-		{
-			type_name = obj->m_name;
-
-			if( !left || !mouse_object->obj )
-			{
-				Set_Mouse_Object( obj );
-			}
-		}
-
-		// ## Set the massivetype text
-		if( col->m_array == ARRAY_MASSIVE )
-		{
-			if( obj->m_massive_type == MASS_HALFMASSIVE )
-			{
-				type_name.insert( 0, _("Halfmassive - ") );
-			}
-			else
-			{
-				type_name.insert( 0, _("Massive - ") );
-			}
-		}
-		else if( col->m_array == ARRAY_PASSIVE )
-		{
-			if( obj->m_type == TYPE_OW_LINE_START || obj->m_type == TYPE_OW_LINE_END || obj->m_type == TYPE_OW_WAYPOINT )
-			{
-				// ignore
-			}
-			else if( obj->m_type == TYPE_FRONT_PASSIVE )
-			{
-				type_name.insert( 0, _("Front Passive - ") );
-			}
-			else
-			{
-				type_name.insert( 0, _("Passive - ") );
-			}
-		}
-		else if( col->m_array == ARRAY_ACTIVE )
-		{
-			if( obj->m_type == TYPE_HALFMASSIVE )
-			{
-				type_name.insert( 0, _("Halfmassive - ") );
-			}
-			else if( obj->m_type == TYPE_CLIMBABLE )
-			{
-				type_name.insert( 0, _("Climbable - ") );
-			}
-		}
-
-		// if valid object draw position text
-		if( mouse_object->obj )
-		{
-			// position text
-			std::string info = "X : " + int_to_string( static_cast<int>(mouse_object->obj->m_start_pos_x) ) + "  Y : " + int_to_string( static_cast<int>(mouse_object->obj->m_start_pos_y) );
-			
-			if( game_debug )
-			{
-				info.insert( 0, "Start " );
-			}
-
-			// create text surface
-			cGL_Surface *position_info = pFont->Render_Text( pFont->m_font_small, info, white );
-
-
-			// create request
-			cSurface_Request *request = new cSurface_Request();
-			position_info->Blit( static_cast<float>( x + 20 ), static_cast<float>( y + 35 ), 0.52f, request );
-			request->delete_texture = 1;
-
-			// shadow
-			request->shadow_pos = 1;
-			request->shadow_color = black;
-
-			// add request
-			pRenderer->Add( request );
-
-			// cSurface_Request deletes it
-			position_info->m_auto_del_img = 0;
-			delete position_info;
-
-			// if in debug mode draw current position X, Y, Z and if available editor Z
-			if( game_debug )
-			{
-				info = "Curr.  X : " + int_to_string( static_cast<int>(mouse_object->obj->m_pos_x) ) + "  Y : " + int_to_string( static_cast<int>(mouse_object->obj->m_pos_y) ) + "  Z : " + float_to_string( mouse_object->obj->m_pos_z, 6 );
-
-				// if also got editor z position
-				if( obj->m_editor_pos_z != 0 )
-				{
-					info.insert( info.length(), _("  Editor Z : ") + float_to_string( mouse_object->obj->m_editor_pos_z, 6 ) );
-				}
-
-				// create text surface
-				position_info = pFont->Render_Text( pFont->m_font_small, info, white );
-				
-				// create request
-				request = new cSurface_Request();
-				position_info->Blit( static_cast<float>( x + 20 ), static_cast<float>( y + 55 ), 0.52f, request );
-				request->delete_texture = 1;
-
-				// shadow
-				request->shadow_pos = 1;
-				request->shadow_color = black;
-
-				// add request
-				pRenderer->Add( request );
-
-				// cSurface_Request deletes it
-				position_info->m_auto_del_img = 0;
-				delete position_info;
-			}
-		}
-
-		if( pHud_Debug->counter <= 0 )
-		{
-			pHud_Debug->Set_Text( type_name, 1 );
-		}
-	}
-	else
-	{
-		if( !left )
+		if( !m_left )
 		{
 			Clear_Mouse_Object();
-
-			if( !col )
-			{
-				mouse_object->mouse_w = 0;
-				mouse_object->mouse_h = 0;
-			}
 		}
 		else
 		{
 			// no mouse object
-			if( !mouse_object->obj )
+			if( !m_hovering_object->obj )
 			{
 				// clear active object
 				Double_Click( 0 );
@@ -1498,7 +1338,132 @@ void cMouseCursor :: Editor_Update( void )
 				}
 			}
 		}
+
+		return;
 	}
+
+	// mouse object type string
+	std::string type_name;
+
+	// set object data
+	if( col->obj )
+	{
+		type_name = col->obj->m_name;
+
+		if( !m_left || !m_hovering_object->obj )
+		{
+			Set_Mouse_Object( col->obj );
+		}
+	}
+
+	// Set the massivetype text
+	if( col->m_array == ARRAY_MASSIVE )
+	{
+		if( col->obj->m_massive_type == MASS_HALFMASSIVE )
+		{
+			type_name.insert( 0, _("Halfmassive - ") );
+		}
+		else
+		{
+			type_name.insert( 0, _("Massive - ") );
+		}
+	}
+	else if( col->m_array == ARRAY_PASSIVE )
+	{
+		if( col->obj->m_type == TYPE_OW_LINE_START || col->obj->m_type == TYPE_OW_LINE_END || col->obj->m_type == TYPE_OW_WAYPOINT )
+		{
+			// ignore
+		}
+		else if( col->obj->m_type == TYPE_FRONT_PASSIVE )
+		{
+			type_name.insert( 0, _("Front Passive - ") );
+		}
+		else
+		{
+			type_name.insert( 0, _("Passive - ") );
+		}
+	}
+	else if( col->m_array == ARRAY_ACTIVE )
+	{
+		if( col->obj->m_type == TYPE_HALFMASSIVE )
+		{
+			type_name.insert( 0, _("Halfmassive - ") );
+		}
+		else if( col->obj->m_type == TYPE_CLIMBABLE )
+		{
+			type_name.insert( 0, _("Climbable - ") );
+		}
+	}
+
+	// if valid object draw position text
+	if( m_hovering_object->obj )
+	{
+		// position text
+		std::string info = "X : " + int_to_string( static_cast<int>(m_hovering_object->obj->m_start_pos_x) ) + "  Y : " + int_to_string( static_cast<int>(m_hovering_object->obj->m_start_pos_y) );
+		
+		if( game_debug )
+		{
+			info.insert( 0, "Start " );
+		}
+
+		// create text surface
+		cGL_Surface *position_info = pFont->Render_Text( pFont->m_font_small, info, white );
+
+
+		// create request
+		cSurface_Request *request = new cSurface_Request();
+		position_info->Blit( static_cast<float>( m_x + 20 ), static_cast<float>( m_y + 35 ), 0.52f, request );
+		request->delete_texture = 1;
+
+		// shadow
+		request->shadow_pos = 1.0f;
+		request->shadow_color = black;
+
+		// add request
+		pRenderer->Add( request );
+
+		// cSurface_Request deletes it
+		position_info->m_auto_del_img = 0;
+		delete position_info;
+
+		// if in debug mode draw current position X, Y, Z and if available editor Z
+		if( game_debug )
+		{
+			info = "Curr.  X : " + int_to_string( static_cast<int>(m_hovering_object->obj->m_pos_x) ) + "  Y : " + int_to_string( static_cast<int>(m_hovering_object->obj->m_pos_y) ) + "  Z : " + float_to_string( m_hovering_object->obj->m_pos_z, 6 );
+
+			// if also got editor z position
+			if( !Is_Float_Equal( col->obj->m_editor_pos_z, 0.0f ) )
+			{
+				info.insert( info.length(), _("  Editor Z : ") + float_to_string( m_hovering_object->obj->m_editor_pos_z, 6 ) );
+			}
+
+			// create text surface
+			position_info = pFont->Render_Text( pFont->m_font_small, info, white );
+			
+			// create request
+			request = new cSurface_Request();
+			position_info->Blit( static_cast<float>( m_x + 20 ), static_cast<float>( m_y + 55 ), 0.52f, request );
+			request->delete_texture = 1;
+
+			// shadow
+			request->shadow_pos = 1.0f;
+			request->shadow_color = black;
+
+			// add request
+			pRenderer->Add( request );
+
+			// cSurface_Request deletes it
+			position_info->m_auto_del_img = 0;
+			delete position_info;
+		}
+	}
+
+	if( pHud_Debug->m_counter <= 0.0f )
+	{
+		pHud_Debug->Set_Text( type_name, 1 );
+	}
+
+	delete col;
 }
 
 /* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */
