@@ -40,7 +40,13 @@ public:
 	void Save( void );
 
 	// Reset the settings
-	void Default( void );
+	void Reset_All( void );
+	void Reset_Game( void );
+	void Reset_Video( void );
+	void Reset_Audio( void );
+	void Reset_Keyboard( void );
+	void Reset_Joystick( void );
+	void Reset_Editor( void );
 	 // Get settings from current game settings
 	void Update( void );
 	// Set settings to current game settings
@@ -50,67 +56,99 @@ public:
 	// Set new audio settings
 	void Apply_Audio( bool sound, bool music );
 
-	/* *** *** *** Game Settings *** *** *** *** */
+	/* *** *** *** Settings *** *** *** *** */
 
 	// Game
 	// last version of smc which saved the preferences file
-	float game_version;
+	float m_game_version;
 	// default language
-	std::string language;
+	std::string m_language;
 	// player always runs
-	bool always_run;
+	bool m_always_run;
 	// menu level name to load
-	std::string menu_level;
+	std::string m_menu_level;
 	// force the given user data directory
-	std::string force_user_data_dir;
+	std::string m_force_user_data_dir;
 	// smart camera speed
-	float camera_hor_speed, camera_ver_speed;
+	float m_camera_hor_speed, m_camera_ver_speed;
 
 	// Audio
-	bool audio_music, audio_sound;
-	unsigned int audio_hz;
+	bool m_audio_music, m_audio_sound;
+	unsigned int m_audio_hz;
 
 	// Video
-	bool video_fullscreen;
-	Uint16 video_screen_w, video_screen_h;
-	Uint8 video_screen_bpp;
-	bool video_vsync;
+	bool m_video_fullscreen;
+	Uint16 m_video_screen_w, m_video_screen_h;
+	Uint8 m_video_screen_bpp;
+	bool m_video_vsync;
 
 	// Keyboard
 	// key definitions
-	SDLKey key_up, key_down, key_left, key_right, key_jump, key_shoot, key_action;
+	SDLKey m_key_up, m_key_down, m_key_left, m_key_right, m_key_jump, m_key_shoot, m_key_action;
 	// scroll speed
-	float scroll_speed;
+	float m_scroll_speed;
 	// Joystick
-	bool joy_enabled;
+	bool m_joy_enabled;
 	// active joy name
-	std::string joy_name;
+	std::string m_joy_name;
 	// jump with upwards
-	bool joy_analog_jump;
+	bool m_joy_analog_jump;
 	// hor/ver axis used
-	int joy_axis_hor, joy_axis_ver;
+	int m_joy_axis_hor, m_joy_axis_ver;
 	// axis threshold
-	Sint16 joy_axis_threshold;
+	Sint16 m_joy_axis_threshold;
 	// button definitions
-	Uint8 joy_button_jump, joy_button_shoot, joy_button_item, joy_button_action, joy_button_exit;
-
-	// Special
-	// level background images enabled
-	bool level_background_images;
-	// image cache enabled
-	bool image_cache_enabled;
+	Uint8 m_joy_button_jump, m_joy_button_shoot, m_joy_button_item, m_joy_button_action, m_joy_button_exit;
 
 	// Editor
 	// hide mouse if clicked on an object
-	bool editor_mouse_auto_hide;
+	bool m_editor_mouse_auto_hide;
 	// show item images
-	bool editor_show_item_images;
+	bool m_editor_show_item_images;
 	// size of the item images
-	unsigned int editor_item_image_size;
+	unsigned int m_editor_item_image_size;
+
+	// Special
+	// level background images enabled
+	bool m_level_background_images;
+	// image cache enabled
+	bool m_image_cache_enabled;
+
 	/* *** *** *** *** *** *** *** */
 
 	// configuration filename
-	std::string config_filename;
+	std::string m_config_filename;
+
+	/* *** *** *** defaults *** *** *** *** */
+	// Game
+	static const bool m_always_run_default;
+	static const std::string m_menu_level_default;
+	static const float m_camera_hor_speed_default, m_camera_ver_speed_default;
+	// Audio
+	static const bool m_audio_music_default, m_audio_sound_default;
+	static const unsigned int m_audio_hz_default;
+	static const Uint8 m_sound_volume_default;
+	static const Uint8 m_music_volume_default;
+	// Video
+	static const bool m_video_fullscreen_default;
+	static const Uint16 m_video_screen_w_default, m_video_screen_h_default;
+	static const Uint8 m_video_screen_bpp_default;
+	static const bool m_video_vsync_default;
+	static const float m_geometry_quality_default;
+	static const float m_texture_quality_default;
+	// Keyboard
+	static const SDLKey m_key_up_default, m_key_down_default, m_key_left_default, m_key_right_default, m_key_jump_default, m_key_shoot_default, m_key_action_default;
+	static const float m_scroll_speed_default;
+	// Joystick
+	static const bool m_joy_enabled_default;
+	static const bool m_joy_analog_jump_default;
+	static const int m_joy_axis_hor_default, m_joy_axis_ver_default;
+	static const Sint16 m_joy_axis_threshold_default;
+	static const Uint8 m_joy_button_jump_default, m_joy_button_shoot_default, m_joy_button_item_default, m_joy_button_action_default, m_joy_button_exit_default;
+	// Editor
+	static const bool m_editor_mouse_auto_hide_default;
+	static const bool m_editor_show_item_images_default;
+	static const unsigned int m_editor_item_image_size_default;
 
 private:
 	// XML element start
